types

package
v0.0.0-...-68f2935 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2024 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AccessDeniedException

type AccessDeniedException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

The operation failed because the calling identity doesn't have the minimum required permissions.

func (*AccessDeniedException) Error

func (e *AccessDeniedException) Error() string

func (*AccessDeniedException) ErrorCode

func (e *AccessDeniedException) ErrorCode() string

func (*AccessDeniedException) ErrorFault

func (e *AccessDeniedException) ErrorFault() smithy.ErrorFault

func (*AccessDeniedException) ErrorMessage

func (e *AccessDeniedException) ErrorMessage() string

type AlternateContact

type AlternateContact struct {

	// The type of alternate contact.
	AlternateContactType AlternateContactType

	// The email address associated with this alternate contact.
	EmailAddress *string

	// The name associated with this alternate contact.
	Name *string

	// The phone number associated with this alternate contact.
	PhoneNumber *string

	// The title associated with this alternate contact.
	Title *string
	// contains filtered or unexported fields
}

A structure that contains the details of an alternate contact associated with an Amazon Web Services account

type AlternateContactType

type AlternateContactType string
const (
	AlternateContactTypeBilling    AlternateContactType = "BILLING"
	AlternateContactTypeOperations AlternateContactType = "OPERATIONS"
	AlternateContactTypeSecurity   AlternateContactType = "SECURITY"
)

Enum values for AlternateContactType

func (AlternateContactType) Values

Values returns all known values for AlternateContactType. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type ConflictException

type ConflictException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

The request could not be processed because of a conflict in the current status of the resource. For example, this happens if you try to enable a Region that is currently being disabled (in a status of DISABLING).

func (*ConflictException) Error

func (e *ConflictException) Error() string

func (*ConflictException) ErrorCode

func (e *ConflictException) ErrorCode() string

func (*ConflictException) ErrorFault

func (e *ConflictException) ErrorFault() smithy.ErrorFault

func (*ConflictException) ErrorMessage

func (e *ConflictException) ErrorMessage() string

type ContactInformation

type ContactInformation struct {

	// The first line of the primary contact address.
	//
	// This member is required.
	AddressLine1 *string

	// The city of the primary contact address.
	//
	// This member is required.
	City *string

	// The ISO-3166 two-letter country code for the primary contact address.
	//
	// This member is required.
	CountryCode *string

	// The full name of the primary contact address.
	//
	// This member is required.
	FullName *string

	// The phone number of the primary contact information. The number will be
	// validated and, in some countries, checked for activation.
	//
	// This member is required.
	PhoneNumber *string

	// The postal code of the primary contact address.
	//
	// This member is required.
	PostalCode *string

	// The second line of the primary contact address, if any.
	AddressLine2 *string

	// The third line of the primary contact address, if any.
	AddressLine3 *string

	// The name of the company associated with the primary contact information, if any.
	CompanyName *string

	// The district or county of the primary contact address, if any.
	DistrictOrCounty *string

	// The state or region of the primary contact address. This field is required in
	// selected countries.
	StateOrRegion *string

	// The URL of the website associated with the primary contact information, if any.
	WebsiteUrl *string
	// contains filtered or unexported fields
}

Contains the details of the primary contact information associated with an Amazon Web Services account.

type InternalServerException

type InternalServerException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

The operation failed because of an error internal to Amazon Web Services. Try your operation again later.

func (*InternalServerException) Error

func (e *InternalServerException) Error() string

func (*InternalServerException) ErrorCode

func (e *InternalServerException) ErrorCode() string

func (*InternalServerException) ErrorFault

func (e *InternalServerException) ErrorFault() smithy.ErrorFault

func (*InternalServerException) ErrorMessage

func (e *InternalServerException) ErrorMessage() string

type Region

type Region struct {

	// The Region code of a given Region (for example, us-east-1 ).
	RegionName *string

	// One of potential statuses a Region can undergo (Enabled, Enabling, Disabled,
	// Disabling, Enabled_By_Default).
	RegionOptStatus RegionOptStatus
	// contains filtered or unexported fields
}

This is a structure that expresses the Region for a given account, consisting of a name and opt-in status.

type RegionOptStatus

type RegionOptStatus string
const (
	RegionOptStatusEnabled          RegionOptStatus = "ENABLED"
	RegionOptStatusEnabling         RegionOptStatus = "ENABLING"
	RegionOptStatusDisabling        RegionOptStatus = "DISABLING"
	RegionOptStatusDisabled         RegionOptStatus = "DISABLED"
	RegionOptStatusEnabledByDefault RegionOptStatus = "ENABLED_BY_DEFAULT"
)

Enum values for RegionOptStatus

func (RegionOptStatus) Values

func (RegionOptStatus) Values() []RegionOptStatus

Values returns all known values for RegionOptStatus. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type ResourceNotFoundException

type ResourceNotFoundException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

The operation failed because it specified a resource that can't be found.

func (*ResourceNotFoundException) Error

func (e *ResourceNotFoundException) Error() string

func (*ResourceNotFoundException) ErrorCode

func (e *ResourceNotFoundException) ErrorCode() string

func (*ResourceNotFoundException) ErrorFault

func (*ResourceNotFoundException) ErrorMessage

func (e *ResourceNotFoundException) ErrorMessage() string

type TooManyRequestsException

type TooManyRequestsException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

The operation failed because it was called too frequently and exceeded a throttle limit.

func (*TooManyRequestsException) Error

func (e *TooManyRequestsException) Error() string

func (*TooManyRequestsException) ErrorCode

func (e *TooManyRequestsException) ErrorCode() string

func (*TooManyRequestsException) ErrorFault

func (e *TooManyRequestsException) ErrorFault() smithy.ErrorFault

func (*TooManyRequestsException) ErrorMessage

func (e *TooManyRequestsException) ErrorMessage() string

type ValidationException

type ValidationException struct {
	Message *string

	ErrorCodeOverride *string

	Reason    ValidationExceptionReason
	FieldList []ValidationExceptionField
	// contains filtered or unexported fields
}

The operation failed because one of the input parameters was invalid.

func (*ValidationException) Error

func (e *ValidationException) Error() string

func (*ValidationException) ErrorCode

func (e *ValidationException) ErrorCode() string

func (*ValidationException) ErrorFault

func (e *ValidationException) ErrorFault() smithy.ErrorFault

func (*ValidationException) ErrorMessage

func (e *ValidationException) ErrorMessage() string

type ValidationExceptionField

type ValidationExceptionField struct {

	// A message about the validation exception.
	//
	// This member is required.
	Message *string

	// The field name where the invalid entry was detected.
	//
	// This member is required.
	Name *string
	// contains filtered or unexported fields
}

The input failed to meet the constraints specified by the Amazon Web Services service in a specified field.

type ValidationExceptionReason

type ValidationExceptionReason string
const (
	ValidationExceptionReasonInvalidRegionOptTarget ValidationExceptionReason = "invalidRegionOptTarget"
	ValidationExceptionReasonFieldValidationFailed  ValidationExceptionReason = "fieldValidationFailed"
)

Enum values for ValidationExceptionReason

func (ValidationExceptionReason) Values

Values returns all known values for ValidationExceptionReason. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

Source Files

  • enums.go
  • errors.go
  • types.go

Jump to