Documentation
¶
Index ¶
- type AccessDeniedException
- type ApplicationAssociationSummary
- type ApplicationSourceConfig
- type ApplicationSummary
- type DataIntegrationAssociationSummary
- type DataIntegrationSummary
- type DuplicateResourceException
- type EventFilter
- type EventIntegration
- type EventIntegrationAssociation
- type ExternalUrlConfig
- type FileConfiguration
- type InternalServiceError
- type InvalidRequestException
- type Publication
- type ResourceNotFoundException
- type ResourceQuotaExceededException
- type ScheduleConfiguration
- type Subscription
- type ThrottlingException
- type UnsupportedOperationException
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccessDeniedException ¶
type AccessDeniedException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
You do not have sufficient access to perform this action.
func (*AccessDeniedException) Error ¶
func (e *AccessDeniedException) Error() string
func (*AccessDeniedException) ErrorCode ¶
func (e *AccessDeniedException) ErrorCode() string
func (*AccessDeniedException) ErrorFault ¶
func (e *AccessDeniedException) ErrorFault() smithy.ErrorFault
func (*AccessDeniedException) ErrorMessage ¶
func (e *AccessDeniedException) ErrorMessage() string
type ApplicationAssociationSummary ¶
type ApplicationAssociationSummary struct {
// The Amazon Resource Name (ARN) of the Application.
ApplicationArn *string
// The Amazon Resource Name (ARN) of the Application Association.
ApplicationAssociationArn *string
// The identifier for the client that is associated with the Application
// Association.
ClientId *string
// contains filtered or unexported fields
}
Summary information about the Application Association.
type ApplicationSourceConfig ¶
type ApplicationSourceConfig struct {
// The external URL source for the application.
ExternalUrlConfig *ExternalUrlConfig
// contains filtered or unexported fields
}
The configuration for where the application should be loaded from.
type ApplicationSummary ¶
type ApplicationSummary struct {
// The Amazon Resource Name (ARN) of the Application.
Arn *string
// The time when the application was created.
CreatedTime *time.Time
// A unique identifier for the Application.
Id *string
// The time when the application was last modified.
LastModifiedTime *time.Time
// The name of the application.
Name *string
// The namespace of the application.
Namespace *string
// contains filtered or unexported fields
}
Summary information about the Application.
type DataIntegrationAssociationSummary ¶
type DataIntegrationAssociationSummary struct {
// The identifier for the client that is associated with the DataIntegration
// association.
ClientId *string
// The Amazon Resource Name (ARN) of the DataIntegration.
DataIntegrationArn *string
// The Amazon Resource Name (ARN) of the DataIntegration association.
DataIntegrationAssociationArn *string
// contains filtered or unexported fields
}
Summary information about the DataIntegration association.
type DataIntegrationSummary ¶
type DataIntegrationSummary struct {
// The Amazon Resource Name (ARN) of the DataIntegration.
Arn *string
// The name of the DataIntegration.
Name *string
// The URI of the data source.
SourceURI *string
// contains filtered or unexported fields
}
Summary information about the DataIntegration.
type DuplicateResourceException ¶
type DuplicateResourceException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
A resource with the specified name already exists.
func (*DuplicateResourceException) Error ¶
func (e *DuplicateResourceException) Error() string
func (*DuplicateResourceException) ErrorCode ¶
func (e *DuplicateResourceException) ErrorCode() string
func (*DuplicateResourceException) ErrorFault ¶
func (e *DuplicateResourceException) ErrorFault() smithy.ErrorFault
func (*DuplicateResourceException) ErrorMessage ¶
func (e *DuplicateResourceException) ErrorMessage() string
type EventFilter ¶
type EventFilter struct {
// The source of the events.
//
// This member is required.
Source *string
// contains filtered or unexported fields
}
The event filter.
type EventIntegration ¶
type EventIntegration struct {
// The event integration description.
Description *string
// The Amazon EventBridge bus for the event integration.
EventBridgeBus *string
// The event integration filter.
EventFilter *EventFilter
// The Amazon Resource Name (ARN) of the event integration.
EventIntegrationArn *string
// The name of the event integration.
Name *string
// The tags used to organize, track, or control access for this resource. For
// example, { "tags": {"key1":"value1", "key2":"value2"} }.
Tags map[string]string
// contains filtered or unexported fields
}
The event integration.
type EventIntegrationAssociation ¶
type EventIntegrationAssociation struct {
// The metadata associated with the client.
ClientAssociationMetadata map[string]string
// The identifier for the client that is associated with the event integration.
ClientId *string
// The name of the EventBridge rule.
EventBridgeRuleName *string
// The Amazon Resource Name (ARN) for the event integration association.
EventIntegrationAssociationArn *string
// The identifier for the event integration association.
EventIntegrationAssociationId *string
// The name of the event integration.
EventIntegrationName *string
// contains filtered or unexported fields
}
The event integration association.
type ExternalUrlConfig ¶
type ExternalUrlConfig struct {
// The URL to access the application.
//
// This member is required.
AccessUrl *string
// Additional URLs to allow list if different than the access URL.
ApprovedOrigins []string
// contains filtered or unexported fields
}
The external URL source for the application.
type FileConfiguration ¶
type FileConfiguration struct {
// Identifiers for the source folders to pull all files from recursively.
//
// This member is required.
Folders []string
// Restrictions for what files should be pulled from the source.
Filters map[string][]string
// contains filtered or unexported fields
}
The configuration for what files should be pulled from the source.
type InternalServiceError ¶
type InternalServiceError struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
Request processing failed due to an error or failure with the service.
func (*InternalServiceError) Error ¶
func (e *InternalServiceError) Error() string
func (*InternalServiceError) ErrorCode ¶
func (e *InternalServiceError) ErrorCode() string
func (*InternalServiceError) ErrorFault ¶
func (e *InternalServiceError) ErrorFault() smithy.ErrorFault
func (*InternalServiceError) ErrorMessage ¶
func (e *InternalServiceError) ErrorMessage() string
type InvalidRequestException ¶
type InvalidRequestException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The request is not valid.
func (*InvalidRequestException) Error ¶
func (e *InvalidRequestException) Error() string
func (*InvalidRequestException) ErrorCode ¶
func (e *InvalidRequestException) ErrorCode() string
func (*InvalidRequestException) ErrorFault ¶
func (e *InvalidRequestException) ErrorFault() smithy.ErrorFault
func (*InvalidRequestException) ErrorMessage ¶
func (e *InvalidRequestException) ErrorMessage() string
type Publication ¶
type Publication struct {
// The name of the publication.
//
// This member is required.
Event *string
// The JSON schema of the publication event.
//
// This member is required.
Schema *string
// The description of the publication.
Description *string
// contains filtered or unexported fields
}
The configuration of an event that the application publishes.
type ResourceNotFoundException ¶
type ResourceNotFoundException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The specified resource was not found.
func (*ResourceNotFoundException) Error ¶
func (e *ResourceNotFoundException) Error() string
func (*ResourceNotFoundException) ErrorCode ¶
func (e *ResourceNotFoundException) ErrorCode() string
func (*ResourceNotFoundException) ErrorFault ¶
func (e *ResourceNotFoundException) ErrorFault() smithy.ErrorFault
func (*ResourceNotFoundException) ErrorMessage ¶
func (e *ResourceNotFoundException) ErrorMessage() string
type ResourceQuotaExceededException ¶
type ResourceQuotaExceededException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The allowed quota for the resource has been exceeded.
func (*ResourceQuotaExceededException) Error ¶
func (e *ResourceQuotaExceededException) Error() string
func (*ResourceQuotaExceededException) ErrorCode ¶
func (e *ResourceQuotaExceededException) ErrorCode() string
func (*ResourceQuotaExceededException) ErrorFault ¶
func (e *ResourceQuotaExceededException) ErrorFault() smithy.ErrorFault
func (*ResourceQuotaExceededException) ErrorMessage ¶
func (e *ResourceQuotaExceededException) ErrorMessage() string
type ScheduleConfiguration ¶
type ScheduleConfiguration struct {
// How often the data should be pulled from data source.
//
// This member is required.
ScheduleExpression *string
// The start date for objects to import in the first flow run as an Unix/epoch
// timestamp in milliseconds or in ISO-8601 format.
FirstExecutionFrom *string
// The name of the object to pull from the data source.
Object *string
// contains filtered or unexported fields
}
The name of the data and how often it should be pulled from the source.
type Subscription ¶
type Subscription struct {
// The name of the subscription.
//
// This member is required.
Event *string
// The description of the subscription.
Description *string
// contains filtered or unexported fields
}
The configuration of an event that the application subscribes.
type ThrottlingException ¶
type ThrottlingException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The throttling limit has been exceeded.
func (*ThrottlingException) Error ¶
func (e *ThrottlingException) Error() string
func (*ThrottlingException) ErrorCode ¶
func (e *ThrottlingException) ErrorCode() string
func (*ThrottlingException) ErrorFault ¶
func (e *ThrottlingException) ErrorFault() smithy.ErrorFault
func (*ThrottlingException) ErrorMessage ¶
func (e *ThrottlingException) ErrorMessage() string
type UnsupportedOperationException ¶
type UnsupportedOperationException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The operation is not supported.
func (*UnsupportedOperationException) Error ¶
func (e *UnsupportedOperationException) Error() string
func (*UnsupportedOperationException) ErrorCode ¶
func (e *UnsupportedOperationException) ErrorCode() string
func (*UnsupportedOperationException) ErrorFault ¶
func (e *UnsupportedOperationException) ErrorFault() smithy.ErrorFault
func (*UnsupportedOperationException) ErrorMessage ¶
func (e *UnsupportedOperationException) ErrorMessage() string
Source Files
¶
- errors.go
- types.go