Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AuditEvent ¶
type AuditEvent struct {
// The content of an audit event that comes from the event, such as userIdentity ,
// userAgent , and eventSource .
//
// This member is required.
EventData *string
// The original event ID from the source event.
//
// This member is required.
Id *string
// A checksum is a base64-SHA256 algorithm that helps you verify that CloudTrail
// receives the event that matches with the checksum. Calculate the checksum by
// running a command like the following:
//
// printf %s $eventdata | openssl dgst -binary -sha256 | base64
EventDataChecksum *string
// contains filtered or unexported fields
}
An event from a source outside of Amazon Web Services that you want CloudTrail to log.
type AuditEventResultEntry ¶
type AuditEventResultEntry struct {
// The event ID assigned by CloudTrail.
//
// This member is required.
EventID *string
// The original event ID from the source event.
//
// This member is required.
Id *string
// contains filtered or unexported fields
}
A response that includes successful and failed event results.
type ChannelInsufficientPermission ¶
type ChannelInsufficientPermission struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The caller's account ID must be the same as the channel owner's account ID.
func (*ChannelInsufficientPermission) Error ¶
func (e *ChannelInsufficientPermission) Error() string
func (*ChannelInsufficientPermission) ErrorCode ¶
func (e *ChannelInsufficientPermission) ErrorCode() string
func (*ChannelInsufficientPermission) ErrorFault ¶
func (e *ChannelInsufficientPermission) ErrorFault() smithy.ErrorFault
func (*ChannelInsufficientPermission) ErrorMessage ¶
func (e *ChannelInsufficientPermission) ErrorMessage() string
type ChannelNotFound ¶
type ChannelNotFound struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The channel could not be found.
func (*ChannelNotFound) Error ¶
func (e *ChannelNotFound) Error() string
func (*ChannelNotFound) ErrorCode ¶
func (e *ChannelNotFound) ErrorCode() string
func (*ChannelNotFound) ErrorFault ¶
func (e *ChannelNotFound) ErrorFault() smithy.ErrorFault
func (*ChannelNotFound) ErrorMessage ¶
func (e *ChannelNotFound) ErrorMessage() string
type ChannelUnsupportedSchema ¶
type ChannelUnsupportedSchema struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The schema type of the event is not supported.
func (*ChannelUnsupportedSchema) Error ¶
func (e *ChannelUnsupportedSchema) Error() string
func (*ChannelUnsupportedSchema) ErrorCode ¶
func (e *ChannelUnsupportedSchema) ErrorCode() string
func (*ChannelUnsupportedSchema) ErrorFault ¶
func (e *ChannelUnsupportedSchema) ErrorFault() smithy.ErrorFault
func (*ChannelUnsupportedSchema) ErrorMessage ¶
func (e *ChannelUnsupportedSchema) ErrorMessage() string
type DuplicatedAuditEventId ¶
type DuplicatedAuditEventId struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
Two or more entries in the request have the same event ID.
func (*DuplicatedAuditEventId) Error ¶
func (e *DuplicatedAuditEventId) Error() string
func (*DuplicatedAuditEventId) ErrorCode ¶
func (e *DuplicatedAuditEventId) ErrorCode() string
func (*DuplicatedAuditEventId) ErrorFault ¶
func (e *DuplicatedAuditEventId) ErrorFault() smithy.ErrorFault
func (*DuplicatedAuditEventId) ErrorMessage ¶
func (e *DuplicatedAuditEventId) ErrorMessage() string
type InvalidChannelARN ¶
type InvalidChannelARN struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The specified channel ARN is not a valid channel ARN.
func (*InvalidChannelARN) Error ¶
func (e *InvalidChannelARN) Error() string
func (*InvalidChannelARN) ErrorCode ¶
func (e *InvalidChannelARN) ErrorCode() string
func (*InvalidChannelARN) ErrorFault ¶
func (e *InvalidChannelARN) ErrorFault() smithy.ErrorFault
func (*InvalidChannelARN) ErrorMessage ¶
func (e *InvalidChannelARN) ErrorMessage() string
type ResultErrorEntry ¶
type ResultErrorEntry struct {
// The error code for events that could not be ingested by CloudTrail. Possible
// error codes include: FieldTooLong , FieldNotFound , InvalidChecksum ,
// InvalidData , InvalidRecipient , InvalidEventSource , AccountNotSubscribed ,
// Throttling , and InternalFailure .
//
// This member is required.
ErrorCode *string
// The message that describes the error for events that could not be ingested by
// CloudTrail.
//
// This member is required.
ErrorMessage *string
// The original event ID from the source event that could not be ingested by
// CloudTrail.
//
// This member is required.
Id *string
// contains filtered or unexported fields
}
Includes the error code and error message for events that could not be ingested by CloudTrail.
type UnsupportedOperationException ¶
type UnsupportedOperationException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The operation requested is not supported in this region or account.
func (*UnsupportedOperationException) Error ¶
func (e *UnsupportedOperationException) Error() string
func (*UnsupportedOperationException) ErrorCode ¶
func (e *UnsupportedOperationException) ErrorCode() string
func (*UnsupportedOperationException) ErrorFault ¶
func (e *UnsupportedOperationException) ErrorFault() smithy.ErrorFault
func (*UnsupportedOperationException) ErrorMessage ¶
func (e *UnsupportedOperationException) ErrorMessage() string
Source Files
¶
- errors.go
- types.go
Click to show internal directories.
Click to hide internal directories.