types

package
v0.0.0-...-68f2935 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2024 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Examples

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AccessDeniedException

type AccessDeniedException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

You do not have sufficient access to perform this action. HTTP Status Code: 403

func (*AccessDeniedException) Error

func (e *AccessDeniedException) Error() string

func (*AccessDeniedException) ErrorCode

func (e *AccessDeniedException) ErrorCode() string

func (*AccessDeniedException) ErrorFault

func (e *AccessDeniedException) ErrorFault() smithy.ErrorFault

func (*AccessDeniedException) ErrorMessage

func (e *AccessDeniedException) ErrorMessage() string

type AttributeMatchingModel

type AttributeMatchingModel string
const (
	AttributeMatchingModelOneToOne   AttributeMatchingModel = "ONE_TO_ONE"
	AttributeMatchingModelManyToMany AttributeMatchingModel = "MANY_TO_MANY"
)

Enum values for AttributeMatchingModel

func (AttributeMatchingModel) Values

Values returns all known values for AttributeMatchingModel. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type ConflictException

type ConflictException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

The request could not be processed because of conflict in the current state of the resource. Example: Workflow already exists, Schema already exists, Workflow is currently running, etc. HTTP Status Code: 400

func (*ConflictException) Error

func (e *ConflictException) Error() string

func (*ConflictException) ErrorCode

func (e *ConflictException) ErrorCode() string

func (*ConflictException) ErrorFault

func (e *ConflictException) ErrorFault() smithy.ErrorFault

func (*ConflictException) ErrorMessage

func (e *ConflictException) ErrorMessage() string

type DeleteUniqueIdError

type DeleteUniqueIdError struct {

	//  The error type for the batch delete unique ID operation.
	//
	// This member is required.
	ErrorType DeleteUniqueIdErrorType

	// The unique ID that could not be deleted.
	//
	// This member is required.
	UniqueId *string
	// contains filtered or unexported fields
}

The Delete Unique Id error.

type DeleteUniqueIdErrorType

type DeleteUniqueIdErrorType string
const (
	DeleteUniqueIdErrorTypeServiceError    DeleteUniqueIdErrorType = "SERVICE_ERROR"
	DeleteUniqueIdErrorTypeValidationError DeleteUniqueIdErrorType = "VALIDATION_ERROR"
)

Enum values for DeleteUniqueIdErrorType

func (DeleteUniqueIdErrorType) Values

Values returns all known values for DeleteUniqueIdErrorType. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type DeleteUniqueIdStatus

type DeleteUniqueIdStatus string
const (
	DeleteUniqueIdStatusCompleted DeleteUniqueIdStatus = "COMPLETED"
	DeleteUniqueIdStatusAccepted  DeleteUniqueIdStatus = "ACCEPTED"
)

Enum values for DeleteUniqueIdStatus

func (DeleteUniqueIdStatus) Values

Values returns all known values for DeleteUniqueIdStatus. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type DeletedUniqueId

type DeletedUniqueId struct {

	//  The unique ID of the deleted item.
	//
	// This member is required.
	UniqueId *string
	// contains filtered or unexported fields
}

The deleted unique ID.

type ErrorDetails

type ErrorDetails struct {

	// The error message from the job, if there is one.
	ErrorMessage *string
	// contains filtered or unexported fields
}

An object containing an error message, if there was an error.

type ExceedsLimitException

type ExceedsLimitException struct {
	Message *string

	ErrorCodeOverride *string

	QuotaName  *string
	QuotaValue *int32
	// contains filtered or unexported fields
}

The request was rejected because it attempted to create resources beyond the current Entity Resolution account limits. The error message describes the limit exceeded. HTTP Status Code: 402

func (*ExceedsLimitException) Error

func (e *ExceedsLimitException) Error() string

func (*ExceedsLimitException) ErrorCode

func (e *ExceedsLimitException) ErrorCode() string

func (*ExceedsLimitException) ErrorFault

func (e *ExceedsLimitException) ErrorFault() smithy.ErrorFault

func (*ExceedsLimitException) ErrorMessage

func (e *ExceedsLimitException) ErrorMessage() string

type IdMappingJobMetrics

type IdMappingJobMetrics struct {

	// The total number of input records.
	InputRecords *int32

	// The total number of records that did not get processed.
	RecordsNotProcessed *int32

	// The total number of records processed.
	TotalRecordsProcessed *int32
	// contains filtered or unexported fields
}

An object containing InputRecords , TotalRecordsProcessed , MatchIDs , and RecordsNotProcessed .

type IdMappingJobOutputSource

type IdMappingJobOutputSource struct {

	// The S3 path to which Entity Resolution will write the output table.
	//
	// This member is required.
	OutputS3Path *string

	// The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this
	// role to access Amazon Web Services resources on your behalf as part of workflow
	// execution.
	//
	// This member is required.
	RoleArn *string

	// Customer KMS ARN for encryption at rest. If not provided, system will use an
	// Entity Resolution managed KMS key.
	KMSArn *string
	// contains filtered or unexported fields
}

An object containing KMSArn , OutputS3Path , and RoleARN .

type IdMappingTechniques

type IdMappingTechniques struct {

	// The type of ID mapping.
	//
	// This member is required.
	IdMappingType IdMappingType

	// An object which defines any additional configurations required by the provider
	// service.
	ProviderProperties *ProviderProperties
	// contains filtered or unexported fields
}

An object which defines the ID mapping techniques and provider configurations.

type IdMappingType

type IdMappingType string
const (
	IdMappingTypeProvider IdMappingType = "PROVIDER"
)

Enum values for IdMappingType

func (IdMappingType) Values

func (IdMappingType) Values() []IdMappingType

Values returns all known values for IdMappingType. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type IdMappingWorkflowInputSource

type IdMappingWorkflowInputSource struct {

	// An Glue table ARN for the input source table.
	//
	// This member is required.
	InputSourceARN *string

	// The name of the schema to be retrieved.
	SchemaName *string

	// The type of ID namespace. There are two types: SOURCE and TARGET .
	//
	// The SOURCE contains configurations for sourceId data that will be processed in
	// an ID mapping workflow.
	//
	// The TARGET contains a configuration of targetId to which all sourceIds will
	// resolve to.
	Type IdNamespaceType
	// contains filtered or unexported fields
}

An object containing InputSourceARN , SchemaName , and Type .

type IdMappingWorkflowOutputSource

type IdMappingWorkflowOutputSource struct {

	// The S3 path to which Entity Resolution will write the output table.
	//
	// This member is required.
	OutputS3Path *string

	// Customer KMS ARN for encryption at rest. If not provided, system will use an
	// Entity Resolution managed KMS key.
	KMSArn *string
	// contains filtered or unexported fields
}

The output source for the ID mapping workflow.

type IdMappingWorkflowSummary

type IdMappingWorkflowSummary struct {

	// The timestamp of when the workflow was created.
	//
	// This member is required.
	CreatedAt *time.Time

	// The timestamp of when the workflow was last updated.
	//
	// This member is required.
	UpdatedAt *time.Time

	// The ARN (Amazon Resource Name) that Entity Resolution generated for the
	// IdMappingWorkflow .
	//
	// This member is required.
	WorkflowArn *string

	// The name of the workflow.
	//
	// This member is required.
	WorkflowName *string
	// contains filtered or unexported fields
}

A list of IdMappingWorkflowSummary objects, each of which contain the fields WorkflowName , WorkflowArn , CreatedAt , and UpdatedAt .

type IdNamespaceIdMappingWorkflowProperties

type IdNamespaceIdMappingWorkflowProperties struct {

	// The type of ID mapping.
	//
	// This member is required.
	IdMappingType IdMappingType

	// An object which defines any additional configurations required by the provider
	// service.
	ProviderProperties *NamespaceProviderProperties
	// contains filtered or unexported fields
}

An object containing IdMappingType and ProviderProperties .

type IdNamespaceInputSource

type IdNamespaceInputSource struct {

	// An Glue table ARN for the input source table.
	//
	// This member is required.
	InputSourceARN *string

	// The name of the schema.
	SchemaName *string
	// contains filtered or unexported fields
}

An object containing InputSourceARN and SchemaName .

type IdNamespaceSummary

type IdNamespaceSummary struct {

	// The timestamp of when the ID namespace was created.
	//
	// This member is required.
	CreatedAt *time.Time

	// The Amazon Resource Name (ARN) of the ID namespace.
	//
	// This member is required.
	IdNamespaceArn *string

	// The name of the ID namespace.
	//
	// This member is required.
	IdNamespaceName *string

	// The type of ID namespace. There are two types: SOURCE and TARGET .
	//
	// The SOURCE contains configurations for sourceId data that will be processed in
	// an ID mapping workflow.
	//
	// The TARGET contains a configuration of targetId to which all sourceIds will
	// resolve to.
	//
	// This member is required.
	Type IdNamespaceType

	// The timestamp of when the ID namespace was last updated.
	//
	// This member is required.
	UpdatedAt *time.Time

	// The description of the ID namespace.
	Description *string
	// contains filtered or unexported fields
}

A summary of ID namespaces.

type IdNamespaceType

type IdNamespaceType string
const (
	IdNamespaceTypeSource IdNamespaceType = "SOURCE"
	IdNamespaceTypeTarget IdNamespaceType = "TARGET"
)

Enum values for IdNamespaceType

func (IdNamespaceType) Values

func (IdNamespaceType) Values() []IdNamespaceType

Values returns all known values for IdNamespaceType. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type IncrementalRunConfig

type IncrementalRunConfig struct {

	// The type of incremental run. It takes only one value: IMMEDIATE .
	IncrementalRunType IncrementalRunType
	// contains filtered or unexported fields
}

An object which defines an incremental run type and has only incrementalRunType as a field.

type IncrementalRunType

type IncrementalRunType string
const (
	IncrementalRunTypeImmediate IncrementalRunType = "IMMEDIATE"
)

Enum values for IncrementalRunType

func (IncrementalRunType) Values

Values returns all known values for IncrementalRunType. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type InputSource

type InputSource struct {

	// An Glue table ARN for the input source table.
	//
	// This member is required.
	InputSourceARN *string

	// The name of the schema to be retrieved.
	//
	// This member is required.
	SchemaName *string

	// Normalizes the attributes defined in the schema in the input data. For example,
	// if an attribute has an AttributeType of PHONE_NUMBER , and the data in the input
	// table is in a format of 1234567890, Entity Resolution will normalize this field
	// in the output to (123)-456-7890.
	ApplyNormalization *bool
	// contains filtered or unexported fields
}

An object containing InputSourceARN , SchemaName , and ApplyNormalization .

type IntermediateSourceConfiguration

type IntermediateSourceConfiguration struct {

	// The Amazon S3 location (bucket and prefix). For example:
	// s3://provider_bucket/DOC-EXAMPLE-BUCKET
	//
	// This member is required.
	IntermediateS3Path *string
	// contains filtered or unexported fields
}

The Amazon S3 location that temporarily stores your data while it processes. Your information won't be saved permanently.

type InternalServerException

type InternalServerException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

This exception occurs when there is an internal failure in the Entity Resolution service. HTTP Status Code: 500

func (*InternalServerException) Error

func (e *InternalServerException) Error() string

func (*InternalServerException) ErrorCode

func (e *InternalServerException) ErrorCode() string

func (*InternalServerException) ErrorFault

func (e *InternalServerException) ErrorFault() smithy.ErrorFault

func (*InternalServerException) ErrorMessage

func (e *InternalServerException) ErrorMessage() string

type JobMetrics

type JobMetrics struct {

	// The total number of input records.
	InputRecords *int32

	// The total number of matchID s generated.
	MatchIDs *int32

	// The total number of records that did not get processed.
	RecordsNotProcessed *int32

	// The total number of records processed.
	TotalRecordsProcessed *int32
	// contains filtered or unexported fields
}

An object containing InputRecords , TotalRecordsProcessed , MatchIDs , and RecordsNotProcessed .

type JobOutputSource

type JobOutputSource struct {

	// The S3 path to which Entity Resolution will write the output table.
	//
	// This member is required.
	OutputS3Path *string

	// The Amazon Resource Name (ARN) of the IAM role. Entity Resolution assumes this
	// role to access Amazon Web Services resources on your behalf as part of workflow
	// execution.
	//
	// This member is required.
	RoleArn *string

	// Customer KMS ARN for encryption at rest. If not provided, system will use an
	// Entity Resolution managed KMS key.
	KMSArn *string
	// contains filtered or unexported fields
}

An object containing KMSArn , OutputS3Path , and RoleArn .

type JobStatus

type JobStatus string
const (
	JobStatusRunning   JobStatus = "RUNNING"
	JobStatusSucceeded JobStatus = "SUCCEEDED"
	JobStatusFailed    JobStatus = "FAILED"
	JobStatusQueued    JobStatus = "QUEUED"
)

Enum values for JobStatus

func (JobStatus) Values

func (JobStatus) Values() []JobStatus

Values returns all known values for JobStatus. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type JobSummary

type JobSummary struct {

	// The ID of the job.
	//
	// This member is required.
	JobId *string

	// The time at which the job was started.
	//
	// This member is required.
	StartTime *time.Time

	// The current status of the job.
	//
	// This member is required.
	Status JobStatus

	// The time at which the job has finished.
	EndTime *time.Time
	// contains filtered or unexported fields
}

An object containing the JobId , Status , StartTime , and EndTime of a job.

type MatchingWorkflowSummary

type MatchingWorkflowSummary struct {

	// The timestamp of when the workflow was created.
	//
	// This member is required.
	CreatedAt *time.Time

	// The method that has been specified for data matching, either using matching
	// provided by Entity Resolution or through a provider service.
	//
	// This member is required.
	ResolutionType ResolutionType

	// The timestamp of when the workflow was last updated.
	//
	// This member is required.
	UpdatedAt *time.Time

	// The ARN (Amazon Resource Name) that Entity Resolution generated for the
	// MatchingWorkflow .
	//
	// This member is required.
	WorkflowArn *string

	// The name of the workflow.
	//
	// This member is required.
	WorkflowName *string
	// contains filtered or unexported fields
}

A list of MatchingWorkflowSummary objects, each of which contain the fields WorkflowName , WorkflowArn , CreatedAt , UpdatedAt .

type NamespaceProviderProperties

type NamespaceProviderProperties struct {

	// The Amazon Resource Name (ARN) of the provider service.
	//
	// This member is required.
	ProviderServiceArn *string

	// An object which defines any additional configurations required by the provider
	// service.
	ProviderConfiguration document.Interface
	// contains filtered or unexported fields
}

An object containing ProviderConfiguration and ProviderServiceArn .

type OutputAttribute

type OutputAttribute struct {

	// A name of a column to be written to the output. This must be an InputField name
	// in the schema mapping.
	//
	// This member is required.
	Name *string

	// Enables the ability to hash the column values in the output.
	Hashed *bool
	// contains filtered or unexported fields
}

A list of OutputAttribute objects, each of which have the fields Name and Hashed . Each of these objects selects a column to be included in the output table, and whether the values of the column should be hashed.

type OutputSource

type OutputSource struct {

	// A list of OutputAttribute objects, each of which have the fields Name and Hashed
	// . Each of these objects selects a column to be included in the output table, and
	// whether the values of the column should be hashed.
	//
	// This member is required.
	Output []OutputAttribute

	// The S3 path to which Entity Resolution will write the output table.
	//
	// This member is required.
	OutputS3Path *string

	// Normalizes the attributes defined in the schema in the input data. For example,
	// if an attribute has an AttributeType of PHONE_NUMBER , and the data in the input
	// table is in a format of 1234567890, Entity Resolution will normalize this field
	// in the output to (123)-456-7890.
	ApplyNormalization *bool

	// Customer KMS ARN for encryption at rest. If not provided, system will use an
	// Entity Resolution managed KMS key.
	KMSArn *string
	// contains filtered or unexported fields
}

A list of OutputAttribute objects, each of which have the fields Name and Hashed . Each of these objects selects a column to be included in the output table, and whether the values of the column should be hashed.

type ProviderComponentSchema

type ProviderComponentSchema struct {

	// The provider schema attributes.
	ProviderSchemaAttributes []ProviderSchemaAttribute

	// Input schema for the provider service.
	Schemas [][]string
	// contains filtered or unexported fields
}

The input schema supported by provider service.

type ProviderEndpointConfiguration

type ProviderEndpointConfiguration interface {
	// contains filtered or unexported methods
}

The required configuration fields to use with the provider service.

The following types satisfy this interface:

ProviderEndpointConfigurationMemberMarketplaceConfiguration
Example (OutputUsage)
// Code generated by smithy-go-codegen DO NOT EDIT.

package main

import (
	"e.coding.net/g-nnjn4981/aito/aws-sdk-go-v2/service/entityresolution/types"
	"fmt"
)

func main() {
	var union types.ProviderEndpointConfiguration
	// type switches can be used to check the union value
	switch v := union.(type) {
	case *types.ProviderEndpointConfigurationMemberMarketplaceConfiguration:
		_ = v.Value // Value is types.ProviderMarketplaceConfiguration

	case *types.UnknownUnionMember:
		fmt.Println("unknown tag:", v.Tag)

	default:
		fmt.Println("union is nil or unknown type")

	}
}

var _ *types.ProviderMarketplaceConfiguration

type ProviderEndpointConfigurationMemberMarketplaceConfiguration

type ProviderEndpointConfigurationMemberMarketplaceConfiguration struct {
	Value ProviderMarketplaceConfiguration
	// contains filtered or unexported fields
}

The identifiers of the provider service, from Data Exchange.

type ProviderIdNameSpaceConfiguration

type ProviderIdNameSpaceConfiguration struct {

	// The description of the ID namespace.
	Description *string

	// Configurations required for the source ID namespace.
	ProviderSourceConfigurationDefinition document.Interface

	// Configurations required for the target ID namespace.
	ProviderTargetConfigurationDefinition document.Interface
	// contains filtered or unexported fields
}

The provider configuration required for different ID namespace types.

type ProviderIntermediateDataAccessConfiguration

type ProviderIntermediateDataAccessConfiguration struct {

	// The Amazon Web Services account that provider can use to read or write data
	// into the customer's intermediate S3 bucket.
	AwsAccountIds []string

	// The S3 bucket actions that the provider requires permission for.
	RequiredBucketActions []string
	// contains filtered or unexported fields
}

The required configuration fields to give intermediate access to a provider service.

type ProviderMarketplaceConfiguration

type ProviderMarketplaceConfiguration struct {

	// The asset ID on Data Exchange.
	//
	// This member is required.
	AssetId *string

	// The dataset ID on Data Exchange.
	//
	// This member is required.
	DataSetId *string

	// The listing ID on Data Exchange.
	//
	// This member is required.
	ListingId *string

	// The revision ID on Data Exchange.
	//
	// This member is required.
	RevisionId *string
	// contains filtered or unexported fields
}

The identifiers of the provider service, from Data Exchange.

type ProviderProperties

type ProviderProperties struct {

	// The ARN of the provider service.
	//
	// This member is required.
	ProviderServiceArn *string

	// The Amazon S3 location that temporarily stores your data while it processes.
	// Your information won't be saved permanently.
	IntermediateSourceConfiguration *IntermediateSourceConfiguration

	// The required configuration fields to use with the provider service.
	ProviderConfiguration document.Interface
	// contains filtered or unexported fields
}

An object containing the providerServiceARN , intermediateSourceConfiguration , and providerConfiguration .

type ProviderSchemaAttribute

type ProviderSchemaAttribute struct {

	// The field name.
	//
	// This member is required.
	FieldName *string

	// The type of the provider schema attribute.
	//
	// This member is required.
	Type SchemaAttributeType

	// The hashing attribute of the provider schema.
	Hashing *bool

	// The sub type of the provider schema attribute.
	SubType *string
	// contains filtered or unexported fields
}

The provider schema attribute.

type ProviderServiceSummary

type ProviderServiceSummary struct {

	// The name of the provider. This name is typically the company name.
	//
	// This member is required.
	ProviderName *string

	// The ARN (Amazon Resource Name) that Entity Resolution generated for the
	// providerService .
	//
	// This member is required.
	ProviderServiceArn *string

	// The display name of the provider service.
	//
	// This member is required.
	ProviderServiceDisplayName *string

	// The name of the product that the provider service provides.
	//
	// This member is required.
	ProviderServiceName *string

	// The type of provider service.
	//
	// This member is required.
	ProviderServiceType ServiceType
	// contains filtered or unexported fields
}

A list of ProviderService objects, each of which contain the fields providerName , providerServiceArn , providerServiceName , and providerServiceType .

type ResolutionTechniques

type ResolutionTechniques struct {

	// The type of matching. There are three types of matching: RULE_MATCHING ,
	// ML_MATCHING , and PROVIDER .
	//
	// This member is required.
	ResolutionType ResolutionType

	// The properties of the provider service.
	ProviderProperties *ProviderProperties

	// An object which defines the list of matching rules to run and has a field Rules
	// , which is a list of rule objects.
	RuleBasedProperties *RuleBasedProperties
	// contains filtered or unexported fields
}

An object which defines the resolutionType and the ruleBasedProperties .

type ResolutionType

type ResolutionType string
const (
	ResolutionTypeRuleMatching ResolutionType = "RULE_MATCHING"
	ResolutionTypeMlMatching   ResolutionType = "ML_MATCHING"
	ResolutionTypeProvider     ResolutionType = "PROVIDER"
)

Enum values for ResolutionType

func (ResolutionType) Values

func (ResolutionType) Values() []ResolutionType

Values returns all known values for ResolutionType. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type ResourceNotFoundException

type ResourceNotFoundException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

The resource could not be found. HTTP Status Code: 404

func (*ResourceNotFoundException) Error

func (e *ResourceNotFoundException) Error() string

func (*ResourceNotFoundException) ErrorCode

func (e *ResourceNotFoundException) ErrorCode() string

func (*ResourceNotFoundException) ErrorFault

func (*ResourceNotFoundException) ErrorMessage

func (e *ResourceNotFoundException) ErrorMessage() string

type Rule

type Rule struct {

	// A list of MatchingKeys . The MatchingKeys must have been defined in the
	// SchemaMapping . Two records are considered to match according to this rule if
	// all of the MatchingKeys match.
	//
	// This member is required.
	MatchingKeys []string

	// A name for the matching rule.
	//
	// This member is required.
	RuleName *string
	// contains filtered or unexported fields
}

An object containing RuleName , and MatchingKeys .

type RuleBasedProperties

type RuleBasedProperties struct {

	// The comparison type. You can either choose ONE_TO_ONE or MANY_TO_MANY as the
	// AttributeMatchingModel. When choosing MANY_TO_MANY , the system can match
	// attributes across the sub-types of an attribute type. For example, if the value
	// of the Email field of Profile A and the value of BusinessEmail field of Profile
	// B matches, the two profiles are matched on the Email type. When choosing
	// ONE_TO_ONE ,the system can only match if the sub-types are exact matches. For
	// example, only when the value of the Email field of Profile A and the value of
	// the Email field of Profile B matches, the two profiles are matched on the Email
	// type.
	//
	// This member is required.
	AttributeMatchingModel AttributeMatchingModel

	// A list of Rule objects, each of which have fields RuleName and MatchingKeys .
	//
	// This member is required.
	Rules []Rule
	// contains filtered or unexported fields
}

An object which defines the list of matching rules to run and has a field Rules , which is a list of rule objects.

type SchemaAttributeType

type SchemaAttributeType string
const (
	SchemaAttributeTypeName              SchemaAttributeType = "NAME"
	SchemaAttributeTypeNameFirst         SchemaAttributeType = "NAME_FIRST"
	SchemaAttributeTypeNameMiddle        SchemaAttributeType = "NAME_MIDDLE"
	SchemaAttributeTypeNameLast          SchemaAttributeType = "NAME_LAST"
	SchemaAttributeTypeAddress           SchemaAttributeType = "ADDRESS"
	SchemaAttributeTypeAddressStreet1    SchemaAttributeType = "ADDRESS_STREET1"
	SchemaAttributeTypeAddressStreet2    SchemaAttributeType = "ADDRESS_STREET2"
	SchemaAttributeTypeAddressStreet3    SchemaAttributeType = "ADDRESS_STREET3"
	SchemaAttributeTypeAddressCity       SchemaAttributeType = "ADDRESS_CITY"
	SchemaAttributeTypeAddressState      SchemaAttributeType = "ADDRESS_STATE"
	SchemaAttributeTypeAddressCountry    SchemaAttributeType = "ADDRESS_COUNTRY"
	SchemaAttributeTypeAddressPostalcode SchemaAttributeType = "ADDRESS_POSTALCODE"
	SchemaAttributeTypePhone             SchemaAttributeType = "PHONE"
	SchemaAttributeTypePhoneNumber       SchemaAttributeType = "PHONE_NUMBER"
	SchemaAttributeTypePhoneCountrycode  SchemaAttributeType = "PHONE_COUNTRYCODE"
	SchemaAttributeTypeEmailAddress      SchemaAttributeType = "EMAIL_ADDRESS"
	SchemaAttributeTypeUniqueId          SchemaAttributeType = "UNIQUE_ID"
	SchemaAttributeTypeDate              SchemaAttributeType = "DATE"
	SchemaAttributeTypeString            SchemaAttributeType = "STRING"
	SchemaAttributeTypeProviderId        SchemaAttributeType = "PROVIDER_ID"
)

Enum values for SchemaAttributeType

func (SchemaAttributeType) Values

Values returns all known values for SchemaAttributeType. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type SchemaInputAttribute

type SchemaInputAttribute struct {

	// A string containing the field name.
	//
	// This member is required.
	FieldName *string

	// The type of the attribute, selected from a list of values.
	//
	// This member is required.
	Type SchemaAttributeType

	// A string that instructs Entity Resolution to combine several columns into a
	// unified column with the identical attribute type.
	//
	// For example, when working with columns such as first_name , middle_name , and
	// last_name , assigning them a common groupName will prompt Entity Resolution to
	// concatenate them into a single value.
	GroupName *string

	// A key that allows grouping of multiple input attributes into a unified matching
	// group. For example, consider a scenario where the source table contains various
	// addresses, such as business_address and shipping_address . By assigning a
	// matchKey called address to both attributes, Entity Resolution will match
	// records across these fields to create a consolidated matching group. If no
	// matchKey is specified for a column, it won't be utilized for matching purposes
	// but will still be included in the output table.
	MatchKey *string

	// The subtype of the attribute, selected from a list of values.
	SubType *string
	// contains filtered or unexported fields
}

An object containing FieldName , Type , GroupName , MatchKey , and SubType .

type SchemaMappingSummary

type SchemaMappingSummary struct {

	// The timestamp of when the SchemaMapping was created.
	//
	// This member is required.
	CreatedAt *time.Time

	// Specifies whether the schema mapping has been applied to a workflow.
	//
	// This member is required.
	HasWorkflows *bool

	// The ARN (Amazon Resource Name) that Entity Resolution generated for the
	// SchemaMapping .
	//
	// This member is required.
	SchemaArn *string

	// The name of the schema.
	//
	// This member is required.
	SchemaName *string

	// The timestamp of when the SchemaMapping was last updated.
	//
	// This member is required.
	UpdatedAt *time.Time
	// contains filtered or unexported fields
}

An object containing SchemaName , SchemaArn , CreatedAt , and UpdatedAt .

type ServiceType

type ServiceType string
const (
	ServiceTypeAssignment ServiceType = "ASSIGNMENT"
	ServiceTypeIdMapping  ServiceType = "ID_MAPPING"
)

Enum values for ServiceType

func (ServiceType) Values

func (ServiceType) Values() []ServiceType

Values returns all known values for ServiceType. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type StatementEffect

type StatementEffect string
const (
	StatementEffectAllow StatementEffect = "Allow"
	StatementEffectDeny  StatementEffect = "Deny"
)

Enum values for StatementEffect

func (StatementEffect) Values

func (StatementEffect) Values() []StatementEffect

Values returns all known values for StatementEffect. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type ThrottlingException

type ThrottlingException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

The request was denied due to request throttling. HTTP Status Code: 429

func (*ThrottlingException) Error

func (e *ThrottlingException) Error() string

func (*ThrottlingException) ErrorCode

func (e *ThrottlingException) ErrorCode() string

func (*ThrottlingException) ErrorFault

func (e *ThrottlingException) ErrorFault() smithy.ErrorFault

func (*ThrottlingException) ErrorMessage

func (e *ThrottlingException) ErrorMessage() string

type UnknownUnionMember

type UnknownUnionMember struct {
	Tag   string
	Value []byte
	// contains filtered or unexported fields
}

UnknownUnionMember is returned when a union member is returned over the wire, but has an unknown tag.

type ValidationException

type ValidationException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

The input fails to satisfy the constraints specified by Entity Resolution. HTTP Status Code: 400

func (*ValidationException) Error

func (e *ValidationException) Error() string

func (*ValidationException) ErrorCode

func (e *ValidationException) ErrorCode() string

func (*ValidationException) ErrorFault

func (e *ValidationException) ErrorFault() smithy.ErrorFault

func (*ValidationException) ErrorMessage

func (e *ValidationException) ErrorMessage() string

Source Files

  • enums.go
  • errors.go
  • types.go

Jump to