Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Attributes ¶
type Attributes struct {
// contains filtered or unexported fields
}
type Device ¶
type Device struct {
// The user specified attributes associated with the device for an event.
Attributes *Attributes
// The unique identifier of the device.
DeviceId *string
// The device type, such as "button".
Type *string
// contains filtered or unexported fields
}
type DeviceDescription ¶
type DeviceDescription struct {
// The ARN of the device.
Arn *string
// An array of zero or more elements of DeviceAttribute objects providing user
// specified device attributes.
Attributes map[string]string
// The unique identifier of the device.
DeviceId *string
// A Boolean value indicating whether or not the device is enabled.
Enabled *bool
// A value between 0 and 1 inclusive, representing the fraction of life remaining
// for the device.
RemainingLife *float64
// The tags currently associated with the AWS IoT 1-Click device.
Tags map[string]string
// The type of the device, such as "button".
Type *string
// contains filtered or unexported fields
}
type DeviceEvent ¶
type DeviceMethod ¶
type ForbiddenException ¶
type ForbiddenException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*ForbiddenException) Error ¶
func (e *ForbiddenException) Error() string
func (*ForbiddenException) ErrorCode ¶
func (e *ForbiddenException) ErrorCode() string
func (*ForbiddenException) ErrorFault ¶
func (e *ForbiddenException) ErrorFault() smithy.ErrorFault
func (*ForbiddenException) ErrorMessage ¶
func (e *ForbiddenException) ErrorMessage() string
type InternalFailureException ¶
type InternalFailureException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*InternalFailureException) Error ¶
func (e *InternalFailureException) Error() string
func (*InternalFailureException) ErrorCode ¶
func (e *InternalFailureException) ErrorCode() string
func (*InternalFailureException) ErrorFault ¶
func (e *InternalFailureException) ErrorFault() smithy.ErrorFault
func (*InternalFailureException) ErrorMessage ¶
func (e *InternalFailureException) ErrorMessage() string
type InvalidRequestException ¶
type InvalidRequestException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*InvalidRequestException) Error ¶
func (e *InvalidRequestException) Error() string
func (*InvalidRequestException) ErrorCode ¶
func (e *InvalidRequestException) ErrorCode() string
func (*InvalidRequestException) ErrorFault ¶
func (e *InvalidRequestException) ErrorFault() smithy.ErrorFault
func (*InvalidRequestException) ErrorMessage ¶
func (e *InvalidRequestException) ErrorMessage() string
type PreconditionFailedException ¶
type PreconditionFailedException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*PreconditionFailedException) Error ¶
func (e *PreconditionFailedException) Error() string
func (*PreconditionFailedException) ErrorCode ¶
func (e *PreconditionFailedException) ErrorCode() string
func (*PreconditionFailedException) ErrorFault ¶
func (e *PreconditionFailedException) ErrorFault() smithy.ErrorFault
func (*PreconditionFailedException) ErrorMessage ¶
func (e *PreconditionFailedException) ErrorMessage() string
type RangeNotSatisfiableException ¶
type RangeNotSatisfiableException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*RangeNotSatisfiableException) Error ¶
func (e *RangeNotSatisfiableException) Error() string
func (*RangeNotSatisfiableException) ErrorCode ¶
func (e *RangeNotSatisfiableException) ErrorCode() string
func (*RangeNotSatisfiableException) ErrorFault ¶
func (e *RangeNotSatisfiableException) ErrorFault() smithy.ErrorFault
func (*RangeNotSatisfiableException) ErrorMessage ¶
func (e *RangeNotSatisfiableException) ErrorMessage() string
type ResourceConflictException ¶
type ResourceConflictException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*ResourceConflictException) Error ¶
func (e *ResourceConflictException) Error() string
func (*ResourceConflictException) ErrorCode ¶
func (e *ResourceConflictException) ErrorCode() string
func (*ResourceConflictException) ErrorFault ¶
func (e *ResourceConflictException) ErrorFault() smithy.ErrorFault
func (*ResourceConflictException) ErrorMessage ¶
func (e *ResourceConflictException) ErrorMessage() string
type ResourceNotFoundException ¶
type ResourceNotFoundException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
func (*ResourceNotFoundException) Error ¶
func (e *ResourceNotFoundException) Error() string
func (*ResourceNotFoundException) ErrorCode ¶
func (e *ResourceNotFoundException) ErrorCode() string
func (*ResourceNotFoundException) ErrorFault ¶
func (e *ResourceNotFoundException) ErrorFault() smithy.ErrorFault
func (*ResourceNotFoundException) ErrorMessage ¶
func (e *ResourceNotFoundException) ErrorMessage() string
Source Files
¶
- errors.go
- types.go
Click to show internal directories.
Click to hide internal directories.