Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClientLimitExceededException ¶
type ClientLimitExceededException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
Your request was throttled because you have exceeded the limit of allowed client calls. Try making the call later.
func (*ClientLimitExceededException) Error ¶
func (e *ClientLimitExceededException) Error() string
func (*ClientLimitExceededException) ErrorCode ¶
func (e *ClientLimitExceededException) ErrorCode() string
func (*ClientLimitExceededException) ErrorFault ¶
func (e *ClientLimitExceededException) ErrorFault() smithy.ErrorFault
func (*ClientLimitExceededException) ErrorMessage ¶
func (e *ClientLimitExceededException) ErrorMessage() string
type IceServer ¶
type IceServer struct {
// A password to login to the ICE server.
Password *string
// The period of time, in seconds, during which the username and password are
// valid.
Ttl *int32
// An array of URIs, in the form specified in the [I-D.petithuguenin-behave-turn-uris] spec. These URIs provide the
// different addresses and/or protocols that can be used to reach the TURN server.
//
// [I-D.petithuguenin-behave-turn-uris]: https://tools.ietf.org/html/draft-petithuguenin-behave-turn-uris-03
Uris []string
// A username to login to the ICE server.
Username *string
// contains filtered or unexported fields
}
A structure for the ICE server connection data.
type InvalidArgumentException ¶
type InvalidArgumentException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The value for this input parameter is invalid.
func (*InvalidArgumentException) Error ¶
func (e *InvalidArgumentException) Error() string
func (*InvalidArgumentException) ErrorCode ¶
func (e *InvalidArgumentException) ErrorCode() string
func (*InvalidArgumentException) ErrorFault ¶
func (e *InvalidArgumentException) ErrorFault() smithy.ErrorFault
func (*InvalidArgumentException) ErrorMessage ¶
func (e *InvalidArgumentException) ErrorMessage() string
type InvalidClientException ¶
type InvalidClientException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The specified client is invalid.
func (*InvalidClientException) Error ¶
func (e *InvalidClientException) Error() string
func (*InvalidClientException) ErrorCode ¶
func (e *InvalidClientException) ErrorCode() string
func (*InvalidClientException) ErrorFault ¶
func (e *InvalidClientException) ErrorFault() smithy.ErrorFault
func (*InvalidClientException) ErrorMessage ¶
func (e *InvalidClientException) ErrorMessage() string
type NotAuthorizedException ¶
type NotAuthorizedException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The caller is not authorized to perform this operation.
func (*NotAuthorizedException) Error ¶
func (e *NotAuthorizedException) Error() string
func (*NotAuthorizedException) ErrorCode ¶
func (e *NotAuthorizedException) ErrorCode() string
func (*NotAuthorizedException) ErrorFault ¶
func (e *NotAuthorizedException) ErrorFault() smithy.ErrorFault
func (*NotAuthorizedException) ErrorMessage ¶
func (e *NotAuthorizedException) ErrorMessage() string
type ResourceNotFoundException ¶
type ResourceNotFoundException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The specified resource is not found.
func (*ResourceNotFoundException) Error ¶
func (e *ResourceNotFoundException) Error() string
func (*ResourceNotFoundException) ErrorCode ¶
func (e *ResourceNotFoundException) ErrorCode() string
func (*ResourceNotFoundException) ErrorFault ¶
func (e *ResourceNotFoundException) ErrorFault() smithy.ErrorFault
func (*ResourceNotFoundException) ErrorMessage ¶
func (e *ResourceNotFoundException) ErrorMessage() string
type SessionExpiredException ¶
type SessionExpiredException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
If the client session is expired. Once the client is connected, the session is valid for 45 minutes. Client should reconnect to the channel to continue sending/receiving messages.
func (*SessionExpiredException) Error ¶
func (e *SessionExpiredException) Error() string
func (*SessionExpiredException) ErrorCode ¶
func (e *SessionExpiredException) ErrorCode() string
func (*SessionExpiredException) ErrorFault ¶
func (e *SessionExpiredException) ErrorFault() smithy.ErrorFault
func (*SessionExpiredException) ErrorMessage ¶
func (e *SessionExpiredException) ErrorMessage() string
Source Files
¶
- enums.go
- errors.go
- types.go
Click to show internal directories.
Click to hide internal directories.