Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccessDeniedException ¶
type AccessDeniedException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
You do not have sufficient access to perform this action.
func (*AccessDeniedException) Error ¶
func (e *AccessDeniedException) Error() string
func (*AccessDeniedException) ErrorCode ¶
func (e *AccessDeniedException) ErrorCode() string
func (*AccessDeniedException) ErrorFault ¶
func (e *AccessDeniedException) ErrorFault() smithy.ErrorFault
func (*AccessDeniedException) ErrorMessage ¶
func (e *AccessDeniedException) ErrorMessage() string
type ConflictException ¶
type ConflictException struct {
Message *string
ErrorCodeOverride *string
ResourceId *string
// contains filtered or unexported fields
}
The request configuration has conflicts. For details, see the accompanying error message.
func (*ConflictException) Error ¶
func (e *ConflictException) Error() string
func (*ConflictException) ErrorCode ¶
func (e *ConflictException) ErrorCode() string
func (*ConflictException) ErrorFault ¶
func (e *ConflictException) ErrorFault() smithy.ErrorFault
func (*ConflictException) ErrorMessage ¶
func (e *ConflictException) ErrorMessage() string
type DeploymentParameterInput ¶
type DeploymentParameterInput struct {
// The desired name of the deployment parameter. This is the identifier on which
// deployment parameters are keyed for a given buyer and product. If this name
// matches an existing deployment parameter, this request will update the existing
// resource.
//
// This member is required.
Name *string
// The text to encrypt and store in the secret.
//
// This member is required.
SecretString *string
// contains filtered or unexported fields
}
The shape containing the requested deployment parameter name and secretString.
type InternalServerException ¶
type InternalServerException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
There was an internal service exception.
func (*InternalServerException) Error ¶
func (e *InternalServerException) Error() string
func (*InternalServerException) ErrorCode ¶
func (e *InternalServerException) ErrorCode() string
func (*InternalServerException) ErrorFault ¶
func (e *InternalServerException) ErrorFault() smithy.ErrorFault
func (*InternalServerException) ErrorMessage ¶
func (e *InternalServerException) ErrorMessage() string
type ResourceNotFoundException ¶
type ResourceNotFoundException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The specified resource wasn't found.
func (*ResourceNotFoundException) Error ¶
func (e *ResourceNotFoundException) Error() string
func (*ResourceNotFoundException) ErrorCode ¶
func (e *ResourceNotFoundException) ErrorCode() string
func (*ResourceNotFoundException) ErrorFault ¶
func (e *ResourceNotFoundException) ErrorFault() smithy.ErrorFault
func (*ResourceNotFoundException) ErrorMessage ¶
func (e *ResourceNotFoundException) ErrorMessage() string
type ServiceQuotaExceededException ¶
type ServiceQuotaExceededException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The maximum number of requests per account has been exceeded.
func (*ServiceQuotaExceededException) Error ¶
func (e *ServiceQuotaExceededException) Error() string
func (*ServiceQuotaExceededException) ErrorCode ¶
func (e *ServiceQuotaExceededException) ErrorCode() string
func (*ServiceQuotaExceededException) ErrorFault ¶
func (e *ServiceQuotaExceededException) ErrorFault() smithy.ErrorFault
func (*ServiceQuotaExceededException) ErrorMessage ¶
func (e *ServiceQuotaExceededException) ErrorMessage() string
type ThrottlingException ¶
type ThrottlingException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
Too many requests.
func (*ThrottlingException) Error ¶
func (e *ThrottlingException) Error() string
func (*ThrottlingException) ErrorCode ¶
func (e *ThrottlingException) ErrorCode() string
func (*ThrottlingException) ErrorFault ¶
func (e *ThrottlingException) ErrorFault() smithy.ErrorFault
func (*ThrottlingException) ErrorMessage ¶
func (e *ThrottlingException) ErrorMessage() string
type ValidationException ¶
type ValidationException struct {
Message *string
ErrorCodeOverride *string
FieldName *string
// contains filtered or unexported fields
}
An error occurred during validation.
func (*ValidationException) Error ¶
func (e *ValidationException) Error() string
func (*ValidationException) ErrorCode ¶
func (e *ValidationException) ErrorCode() string
func (*ValidationException) ErrorFault ¶
func (e *ValidationException) ErrorFault() smithy.ErrorFault
func (*ValidationException) ErrorMessage ¶
func (e *ValidationException) ErrorMessage() string
Source Files
¶
- errors.go
- types.go
Click to show internal directories.
Click to hide internal directories.