types

package
v0.0.0-...-68f2935 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2024 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AccessDeniedException

type AccessDeniedException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

You do not have sufficient access to perform this action.

func (*AccessDeniedException) Error

func (e *AccessDeniedException) Error() string

func (*AccessDeniedException) ErrorCode

func (e *AccessDeniedException) ErrorCode() string

func (*AccessDeniedException) ErrorFault

func (e *AccessDeniedException) ErrorFault() smithy.ErrorFault

func (*AccessDeniedException) ErrorMessage

func (e *AccessDeniedException) ErrorMessage() string

type AddressFamily

type AddressFamily string
const (
	AddressFamilyIpv4 AddressFamily = "IPV4"
	AddressFamilyIpv6 AddressFamily = "IPV6"
)

Enum values for AddressFamily

func (AddressFamily) Values

func (AddressFamily) Values() []AddressFamily

Values returns all known values for AddressFamily. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type ConflictException

type ConflictException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

This operation attempted to create a resource that already exists.

func (*ConflictException) Error

func (e *ConflictException) Error() string

func (*ConflictException) ErrorCode

func (e *ConflictException) ErrorCode() string

func (*ConflictException) ErrorFault

func (e *ConflictException) ErrorFault() smithy.ErrorFault

func (*ConflictException) ErrorMessage

func (e *ConflictException) ErrorMessage() string

type CreateMonitorProbeInput

type CreateMonitorProbeInput struct {

	// The destination IP address. This must be either IPV4 or IPV6 .
	//
	// This member is required.
	Destination *string

	// The protocol used for the network traffic between the source and destination .
	// This must be either TCP or ICMP .
	//
	// This member is required.
	Protocol Protocol

	// The ARN of the subnet.
	//
	// This member is required.
	SourceArn *string

	// The port associated with the destination . This is required only if the protocol
	// is TCP and must be a number between 1 and 65536 .
	DestinationPort *int32

	// The size of the packets sent between the source and destination. This must be a
	// number between 56 and 8500 .
	PacketSize *int32

	// The list of key-value pairs created and assigned to the monitor.
	ProbeTags map[string]string
	// contains filtered or unexported fields
}

Creates a monitor probe.

type InternalServerException

type InternalServerException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

The request processing has failed because of an unknown error, exception or failure.

func (*InternalServerException) Error

func (e *InternalServerException) Error() string

func (*InternalServerException) ErrorCode

func (e *InternalServerException) ErrorCode() string

func (*InternalServerException) ErrorFault

func (e *InternalServerException) ErrorFault() smithy.ErrorFault

func (*InternalServerException) ErrorMessage

func (e *InternalServerException) ErrorMessage() string

type MonitorState

type MonitorState string
const (
	MonitorStatePending  MonitorState = "PENDING"
	MonitorStateActive   MonitorState = "ACTIVE"
	MonitorStateInactive MonitorState = "INACTIVE"
	MonitorStateError    MonitorState = "ERROR"
	MonitorStateDeleting MonitorState = "DELETING"
)

Enum values for MonitorState

func (MonitorState) Values

func (MonitorState) Values() []MonitorState

Values returns all known values for MonitorState. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type MonitorSummary

type MonitorSummary struct {

	// The ARN of the monitor.
	//
	// This member is required.
	MonitorArn *string

	// The name of the monitor.
	//
	// This member is required.
	MonitorName *string

	// The state of the monitor.
	//
	// This member is required.
	State MonitorState

	// The time, in seconds, that metrics are collected and sent to Amazon CloudWatch.
	// Valid values are either 30 or 60 .
	AggregationPeriod *int64

	// The list of key-value pairs assigned to the monitor.
	Tags map[string]string
	// contains filtered or unexported fields
}

Displays summary information about a monitor.

type Probe

type Probe struct {

	// The destination for the probe. This should be either an IPV4 or IPV6 .
	//
	// This member is required.
	Destination *string

	// The network protocol for the destination. This can be either TCP or ICMP . If
	// the protocol is TCP , then port is also required.
	//
	// This member is required.
	Protocol Protocol

	// The ARN of the probe source subnet.
	//
	// This member is required.
	SourceArn *string

	// The IPv4 or IPv6 address for the probe.
	AddressFamily AddressFamily

	// The time and date the probe was created.
	CreatedAt *time.Time

	// The destination port for the probe. This is required only if the protocol is TCP
	// and must be a number between 1 and 65536 .
	DestinationPort *int32

	// The time and date that the probe was last modified.
	ModifiedAt *time.Time

	// The size of the packets traveling between the source and destination . This must
	// be a number between 56 and
	PacketSize *int32

	// The ARN of the probe.
	ProbeArn *string

	// The ID of the probe.
	ProbeId *string

	// The state of the probe.
	State ProbeState

	// The list of key-value pairs created and assigned to the probe.
	Tags map[string]string

	// The ID of the source VPC subnet.
	VpcId *string
	// contains filtered or unexported fields
}

Describes information about a network monitor probe.

type ProbeInput

type ProbeInput struct {

	// The destination IP address. This must be either IPV4 or IPV6 .
	//
	// This member is required.
	Destination *string

	// The protocol used for the network traffic between the source and destination .
	// This must be either TCP or ICMP .
	//
	// This member is required.
	Protocol Protocol

	// The ARN of the subnet.
	//
	// This member is required.
	SourceArn *string

	// The port associated with the destination . This is required only if the protocol
	// is TCP and must be a number between 1 and 65536 .
	DestinationPort *int32

	// The size of the packets sent between the source and destination. This must be a
	// number between 56 and 8500 .
	PacketSize *int32

	// The list of key-value pairs created and assigned to the monitor.
	Tags map[string]string
	// contains filtered or unexported fields
}

Defines a probe when creating a probe or monitor.

type ProbeState

type ProbeState string
const (
	ProbeStatePending  ProbeState = "PENDING"
	ProbeStateActive   ProbeState = "ACTIVE"
	ProbeStateInactive ProbeState = "INACTIVE"
	ProbeStateError    ProbeState = "ERROR"
	ProbeStateDeleting ProbeState = "DELETING"
	ProbeStateDeleted  ProbeState = "DELETED"
)

Enum values for ProbeState

func (ProbeState) Values

func (ProbeState) Values() []ProbeState

Values returns all known values for ProbeState. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type Protocol

type Protocol string
const (
	ProtocolTcp  Protocol = "TCP"
	ProtocolIcmp Protocol = "ICMP"
)

Enum values for Protocol

func (Protocol) Values

func (Protocol) Values() []Protocol

Values returns all known values for Protocol. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type ResourceNotFoundException

type ResourceNotFoundException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

The specified resource does not exist.

func (*ResourceNotFoundException) Error

func (e *ResourceNotFoundException) Error() string

func (*ResourceNotFoundException) ErrorCode

func (e *ResourceNotFoundException) ErrorCode() string

func (*ResourceNotFoundException) ErrorFault

func (*ResourceNotFoundException) ErrorMessage

func (e *ResourceNotFoundException) ErrorMessage() string

type ServiceQuotaExceededException

type ServiceQuotaExceededException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

This request exceeds a service quota.

func (*ServiceQuotaExceededException) Error

func (*ServiceQuotaExceededException) ErrorCode

func (e *ServiceQuotaExceededException) ErrorCode() string

func (*ServiceQuotaExceededException) ErrorFault

func (*ServiceQuotaExceededException) ErrorMessage

func (e *ServiceQuotaExceededException) ErrorMessage() string

type ThrottlingException

type ThrottlingException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

The request was denied due to request throttling

func (*ThrottlingException) Error

func (e *ThrottlingException) Error() string

func (*ThrottlingException) ErrorCode

func (e *ThrottlingException) ErrorCode() string

func (*ThrottlingException) ErrorFault

func (e *ThrottlingException) ErrorFault() smithy.ErrorFault

func (*ThrottlingException) ErrorMessage

func (e *ThrottlingException) ErrorMessage() string

type ValidationException

type ValidationException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

One of the parameters for the request is not valid.

func (*ValidationException) Error

func (e *ValidationException) Error() string

func (*ValidationException) ErrorCode

func (e *ValidationException) ErrorCode() string

func (*ValidationException) ErrorFault

func (e *ValidationException) ErrorFault() smithy.ErrorFault

func (*ValidationException) ErrorMessage

func (e *ValidationException) ErrorMessage() string

Source Files

  • enums.go
  • errors.go
  • types.go

Jump to