Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type InvalidInputException ¶
type InvalidInputException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
Provide a valid value for the field or parameter.
func (*InvalidInputException) Error ¶
func (e *InvalidInputException) Error() string
func (*InvalidInputException) ErrorCode ¶
func (e *InvalidInputException) ErrorCode() string
func (*InvalidInputException) ErrorFault ¶
func (e *InvalidInputException) ErrorFault() smithy.ErrorFault
func (*InvalidInputException) ErrorMessage ¶
func (e *InvalidInputException) ErrorMessage() string
type PredictedAction ¶
type PredictedAction struct {
// The ID of the recommended action.
ActionId *string
// The score of the recommended action. For information about action scores, see [How action recommendation scoring works].
//
// [How action recommendation scoring works]: https://docs.aws.amazon.com/personalize/latest/dg/how-action-recommendation-scoring-works.html
Score *float64
// contains filtered or unexported fields
}
An object that identifies an action.
The API returns a list of PredictedAction s.
type PredictedItem ¶
type PredictedItem struct {
// The recommended item ID.
ItemId *string
// Metadata about the item from your Items dataset.
Metadata map[string]string
// The name of the promotion that included the predicted item.
PromotionName *string
// If you use User-Personalization-v2, a list of reasons for why the item was
// included in recommendations. Possible reasons include the following:
//
// - Promoted item - Indicates the item was included as part of a promotion that
// you applied in your recommendation request.
//
// - Exploration - Indicates the item was included with exploration. With
// exploration, recommendations include items with less interactions data or
// relevance for the user. For more information about exploration, see [Exploration].
//
// - Popular item - Indicates the item was included as a placeholder popular
// item. If you use a filter, depending on how many recommendations the filter
// removes, Amazon Personalize might add placeholder items to meet the numResults
// for your recommendation request. These items are popular items, based on
// interactions data, that satisfy your filter criteria. They don't have a
// relevance score for the user.
//
// [Exploration]: https://docs.aws.amazon.com/personalize/latest/dg/use-case-recipe-features.html#about-exploration
Reason []string
// A numeric representation of the model's certainty that the item will be the
// next user selection. For more information on scoring logic, see how-scores-work.
Score *float64
// contains filtered or unexported fields
}
An object that identifies an item.
The and APIs return a list of PredictedItem s.
type Promotion ¶
type Promotion struct {
// The Amazon Resource Name (ARN) of the filter used by the promotion. This filter
// defines the criteria for promoted items. For more information, see [Promotion filters].
//
// [Promotion filters]: https://docs.aws.amazon.com/personalize/latest/dg/promoting-items.html#promotion-filters
FilterArn *string
// The values to use when promoting items. For each placeholder parameter in your
// promotion's filter expression, provide the parameter name (in matching case) as
// a key and the filter value(s) as the corresponding value. Separate multiple
// values for one parameter with a comma.
//
// For filter expressions that use an INCLUDE element to include items, you must
// provide values for all parameters that are defined in the expression. For
// filters with expressions that use an EXCLUDE element to exclude items, you can
// omit the filter-values . In this case, Amazon Personalize doesn't use that
// portion of the expression to filter recommendations.
//
// For more information on creating filters, see [Filtering recommendations and user segments].
//
// [Filtering recommendations and user segments]: https://docs.aws.amazon.com/personalize/latest/dg/filter.html
FilterValues map[string]string
// The name of the promotion.
Name *string
// The percentage of recommended items to apply the promotion to.
PercentPromotedItems *int32
// contains filtered or unexported fields
}
Contains information on a promotion. A promotion defines additional business rules that apply to a configurable subset of recommended items.
type ResourceNotFoundException ¶
type ResourceNotFoundException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The specified resource does not exist.
func (*ResourceNotFoundException) Error ¶
func (e *ResourceNotFoundException) Error() string
func (*ResourceNotFoundException) ErrorCode ¶
func (e *ResourceNotFoundException) ErrorCode() string
func (*ResourceNotFoundException) ErrorFault ¶
func (e *ResourceNotFoundException) ErrorFault() smithy.ErrorFault
func (*ResourceNotFoundException) ErrorMessage ¶
func (e *ResourceNotFoundException) ErrorMessage() string
Source Files
¶
- errors.go
- types.go
Click to show internal directories.
Click to hide internal directories.