Documentation
¶
Index ¶
- type AlreadyExistsException
- type BadRequestException
- type CallInstructionsMessageType
- type CloudWatchLogsDestination
- type EventDestination
- type EventDestinationDefinition
- type EventType
- type InternalServiceErrorException
- type KinesisFirehoseDestination
- type LimitExceededException
- type NotFoundException
- type PlainTextMessageType
- type SSMLMessageType
- type SnsDestination
- type TooManyRequestsException
- type VoiceMessageContent
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AlreadyExistsException ¶
type AlreadyExistsException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The resource specified in your request already exists.
func (*AlreadyExistsException) Error ¶
func (e *AlreadyExistsException) Error() string
func (*AlreadyExistsException) ErrorCode ¶
func (e *AlreadyExistsException) ErrorCode() string
func (*AlreadyExistsException) ErrorFault ¶
func (e *AlreadyExistsException) ErrorFault() smithy.ErrorFault
func (*AlreadyExistsException) ErrorMessage ¶
func (e *AlreadyExistsException) ErrorMessage() string
type BadRequestException ¶
type BadRequestException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The input you provided is invalid.
func (*BadRequestException) Error ¶
func (e *BadRequestException) Error() string
func (*BadRequestException) ErrorCode ¶
func (e *BadRequestException) ErrorCode() string
func (*BadRequestException) ErrorFault ¶
func (e *BadRequestException) ErrorFault() smithy.ErrorFault
func (*BadRequestException) ErrorMessage ¶
func (e *BadRequestException) ErrorMessage() string
type CallInstructionsMessageType ¶
type CallInstructionsMessageType struct {
// The language to use when delivering the message. For a complete list of
// supported languages, see the Amazon Polly Developer Guide.
Text *string
// contains filtered or unexported fields
}
An object that defines a message that contains text formatted using Amazon Pinpoint Voice Instructions markup.
type CloudWatchLogsDestination ¶
type CloudWatchLogsDestination struct {
// The Amazon Resource Name (ARN) of an Amazon Identity and Access Management
// (IAM) role that is able to write event data to an Amazon CloudWatch destination.
IamRoleArn *string
// The name of the Amazon CloudWatch Log Group that you want to record events in.
LogGroupArn *string
// contains filtered or unexported fields
}
An object that contains information about an event destination that sends data to Amazon CloudWatch Logs.
type EventDestination ¶
type EventDestination struct {
// An object that contains information about an event destination that sends data
// to Amazon CloudWatch Logs.
CloudWatchLogsDestination *CloudWatchLogsDestination
// Indicates whether or not the event destination is enabled. If the event
// destination is enabled, then Amazon Pinpoint sends response data to the
// specified event destination.
Enabled *bool
// An object that contains information about an event destination that sends data
// to Amazon Kinesis Data Firehose.
KinesisFirehoseDestination *KinesisFirehoseDestination
// An array of EventDestination objects. Each EventDestination object includes
// ARNs and other information that define an event destination.
MatchingEventTypes []EventType
// A name that identifies the event destination configuration.
Name *string
// An object that contains information about an event destination that sends data
// to Amazon SNS.
SnsDestination *SnsDestination
// contains filtered or unexported fields
}
An object that defines an event destination.
type EventDestinationDefinition ¶
type EventDestinationDefinition struct {
// An object that contains information about an event destination that sends data
// to Amazon CloudWatch Logs.
CloudWatchLogsDestination *CloudWatchLogsDestination
// Indicates whether or not the event destination is enabled. If the event
// destination is enabled, then Amazon Pinpoint sends response data to the
// specified event destination.
Enabled *bool
// An object that contains information about an event destination that sends data
// to Amazon Kinesis Data Firehose.
KinesisFirehoseDestination *KinesisFirehoseDestination
// An array of EventDestination objects. Each EventDestination object includes
// ARNs and other information that define an event destination.
MatchingEventTypes []EventType
// An object that contains information about an event destination that sends data
// to Amazon SNS.
SnsDestination *SnsDestination
// contains filtered or unexported fields
}
An object that defines a single event destination.
type EventType ¶
type EventType string
const ( EventTypeInitiatedCall EventType = "INITIATED_CALL" EventTypeRinging EventType = "RINGING" EventTypeAnswered EventType = "ANSWERED" EventTypeCompletedCall EventType = "COMPLETED_CALL" EventTypeBusy EventType = "BUSY" EventTypeFailed EventType = "FAILED" EventTypeNoAnswer EventType = "NO_ANSWER" )
Enum values for EventType
type InternalServiceErrorException ¶
type InternalServiceErrorException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The API encountered an unexpected error and couldn't complete the request. You might be able to successfully issue the request again in the future.
func (*InternalServiceErrorException) Error ¶
func (e *InternalServiceErrorException) Error() string
func (*InternalServiceErrorException) ErrorCode ¶
func (e *InternalServiceErrorException) ErrorCode() string
func (*InternalServiceErrorException) ErrorFault ¶
func (e *InternalServiceErrorException) ErrorFault() smithy.ErrorFault
func (*InternalServiceErrorException) ErrorMessage ¶
func (e *InternalServiceErrorException) ErrorMessage() string
type KinesisFirehoseDestination ¶
type KinesisFirehoseDestination struct {
// The Amazon Resource Name (ARN) of an IAM role that can write data to an Amazon
// Kinesis Data Firehose stream.
DeliveryStreamArn *string
// The Amazon Resource Name (ARN) of the Amazon Kinesis Data Firehose destination
// that you want to use in the event destination.
IamRoleArn *string
// contains filtered or unexported fields
}
An object that contains information about an event destination that sends data to Amazon Kinesis Data Firehose.
type LimitExceededException ¶
type LimitExceededException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
There are too many instances of the specified resource type.
func (*LimitExceededException) Error ¶
func (e *LimitExceededException) Error() string
func (*LimitExceededException) ErrorCode ¶
func (e *LimitExceededException) ErrorCode() string
func (*LimitExceededException) ErrorFault ¶
func (e *LimitExceededException) ErrorFault() smithy.ErrorFault
func (*LimitExceededException) ErrorMessage ¶
func (e *LimitExceededException) ErrorMessage() string
type NotFoundException ¶
type NotFoundException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The resource you attempted to access doesn't exist.
func (*NotFoundException) Error ¶
func (e *NotFoundException) Error() string
func (*NotFoundException) ErrorCode ¶
func (e *NotFoundException) ErrorCode() string
func (*NotFoundException) ErrorFault ¶
func (e *NotFoundException) ErrorFault() smithy.ErrorFault
func (*NotFoundException) ErrorMessage ¶
func (e *NotFoundException) ErrorMessage() string
type PlainTextMessageType ¶
type PlainTextMessageType struct {
// The language to use when delivering the message. For a complete list of
// supported languages, see the Amazon Polly Developer Guide.
LanguageCode *string
// The plain (not SSML-formatted) text to deliver to the recipient.
Text *string
// The name of the voice that you want to use to deliver the message. For a
// complete list of supported voices, see the Amazon Polly Developer Guide.
VoiceId *string
// contains filtered or unexported fields
}
An object that defines a message that contains unformatted text.
type SSMLMessageType ¶
type SSMLMessageType struct {
// The language to use when delivering the message. For a complete list of
// supported languages, see the Amazon Polly Developer Guide.
LanguageCode *string
// The SSML-formatted text to deliver to the recipient.
Text *string
// The name of the voice that you want to use to deliver the message. For a
// complete list of supported voices, see the Amazon Polly Developer Guide.
VoiceId *string
// contains filtered or unexported fields
}
An object that defines a message that contains SSML-formatted text.
type SnsDestination ¶
type SnsDestination struct {
// The Amazon Resource Name (ARN) of the Amazon SNS topic that you want to publish
// events to.
TopicArn *string
// contains filtered or unexported fields
}
An object that contains information about an event destination that sends data to Amazon SNS.
type TooManyRequestsException ¶
type TooManyRequestsException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
You've issued too many requests to the resource. Wait a few minutes, and then try again.
func (*TooManyRequestsException) Error ¶
func (e *TooManyRequestsException) Error() string
func (*TooManyRequestsException) ErrorCode ¶
func (e *TooManyRequestsException) ErrorCode() string
func (*TooManyRequestsException) ErrorFault ¶
func (e *TooManyRequestsException) ErrorFault() smithy.ErrorFault
func (*TooManyRequestsException) ErrorMessage ¶
func (e *TooManyRequestsException) ErrorMessage() string
type VoiceMessageContent ¶
type VoiceMessageContent struct {
// An object that defines a message that contains text formatted using Amazon
// Pinpoint Voice Instructions markup.
CallInstructionsMessage *CallInstructionsMessageType
// An object that defines a message that contains unformatted text.
PlainTextMessage *PlainTextMessageType
// An object that defines a message that contains SSML-formatted text.
SSMLMessage *SSMLMessageType
// contains filtered or unexported fields
}
An object that contains a voice message and information about the recipient that you want to send it to.
Source Files
¶
- enums.go
- errors.go
- types.go