Documentation
¶
Index ¶
- type AbortTransactionRequest
- type AbortTransactionResult
- type BadRequestException
- type CapacityExceededException
- type CommitTransactionRequest
- type CommitTransactionResult
- type EndSessionRequest
- type EndSessionResult
- type ExecuteStatementRequest
- type ExecuteStatementResult
- type FetchPageRequest
- type FetchPageResult
- type IOUsage
- type InvalidSessionException
- type LimitExceededException
- type OccConflictException
- type Page
- type RateExceededException
- type StartSessionRequest
- type StartSessionResult
- type StartTransactionRequest
- type StartTransactionResult
- type TimingInformation
- type ValueHolder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AbortTransactionRequest ¶
type AbortTransactionRequest struct {
// contains filtered or unexported fields
}
Contains the details of the transaction to abort.
type AbortTransactionResult ¶
type AbortTransactionResult struct {
// Contains server-side performance information for the command.
TimingInformation *TimingInformation
// contains filtered or unexported fields
}
Contains the details of the aborted transaction.
type BadRequestException ¶
type BadRequestException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
Returned if the request is malformed or contains an error such as an invalid parameter value or a missing required parameter.
func (*BadRequestException) Error ¶
func (e *BadRequestException) Error() string
func (*BadRequestException) ErrorCode ¶
func (e *BadRequestException) ErrorCode() string
func (*BadRequestException) ErrorFault ¶
func (e *BadRequestException) ErrorFault() smithy.ErrorFault
func (*BadRequestException) ErrorMessage ¶
func (e *BadRequestException) ErrorMessage() string
type CapacityExceededException ¶
type CapacityExceededException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
Returned when the request exceeds the processing capacity of the ledger.
func (*CapacityExceededException) Error ¶
func (e *CapacityExceededException) Error() string
func (*CapacityExceededException) ErrorCode ¶
func (e *CapacityExceededException) ErrorCode() string
func (*CapacityExceededException) ErrorFault ¶
func (e *CapacityExceededException) ErrorFault() smithy.ErrorFault
func (*CapacityExceededException) ErrorMessage ¶
func (e *CapacityExceededException) ErrorMessage() string
type CommitTransactionRequest ¶
type CommitTransactionRequest struct {
// Specifies the commit digest for the transaction to commit. For every active
// transaction, the commit digest must be passed. QLDB validates CommitDigest and
// rejects the commit with an error if the digest computed on the client does not
// match the digest computed by QLDB.
//
// The purpose of the CommitDigest parameter is to ensure that QLDB commits a
// transaction if and only if the server has processed the exact set of statements
// sent by the client, in the same order that client sent them, and with no
// duplicates.
//
// This member is required.
CommitDigest []byte
// Specifies the transaction ID of the transaction to commit.
//
// This member is required.
TransactionId *string
// contains filtered or unexported fields
}
Contains the details of the transaction to commit.
type CommitTransactionResult ¶
type CommitTransactionResult struct {
// The commit digest of the committed transaction.
CommitDigest []byte
// Contains metrics about the number of I/O requests that were consumed.
ConsumedIOs *IOUsage
// Contains server-side performance information for the command.
TimingInformation *TimingInformation
// The transaction ID of the committed transaction.
TransactionId *string
// contains filtered or unexported fields
}
Contains the details of the committed transaction.
type EndSessionRequest ¶
type EndSessionRequest struct {
// contains filtered or unexported fields
}
Specifies a request to end the session.
type EndSessionResult ¶
type EndSessionResult struct {
// Contains server-side performance information for the command.
TimingInformation *TimingInformation
// contains filtered or unexported fields
}
Contains the details of the ended session.
type ExecuteStatementRequest ¶
type ExecuteStatementRequest struct {
// Specifies the statement of the request.
//
// This member is required.
Statement *string
// Specifies the transaction ID of the request.
//
// This member is required.
TransactionId *string
// Specifies the parameters for the parameterized statement in the request.
Parameters []ValueHolder
// contains filtered or unexported fields
}
Specifies a request to execute a statement.
type ExecuteStatementResult ¶
type ExecuteStatementResult struct {
// Contains metrics about the number of I/O requests that were consumed.
ConsumedIOs *IOUsage
// Contains the details of the first fetched page.
FirstPage *Page
// Contains server-side performance information for the command.
TimingInformation *TimingInformation
// contains filtered or unexported fields
}
Contains the details of the executed statement.
type FetchPageRequest ¶
type FetchPageRequest struct {
// Specifies the next page token of the page to be fetched.
//
// This member is required.
NextPageToken *string
// Specifies the transaction ID of the page to be fetched.
//
// This member is required.
TransactionId *string
// contains filtered or unexported fields
}
Specifies the details of the page to be fetched.
type FetchPageResult ¶
type FetchPageResult struct {
// Contains metrics about the number of I/O requests that were consumed.
ConsumedIOs *IOUsage
// Contains details of the fetched page.
Page *Page
// Contains server-side performance information for the command.
TimingInformation *TimingInformation
// contains filtered or unexported fields
}
Contains the page that was fetched.
type IOUsage ¶
type IOUsage struct {
// The number of read I/O requests that the command made.
ReadIOs int64
// The number of write I/O requests that the command made.
WriteIOs int64
// contains filtered or unexported fields
}
Contains I/O usage metrics for a command that was invoked.
type InvalidSessionException ¶
type InvalidSessionException struct {
Message *string
ErrorCodeOverride *string
Code *string
// contains filtered or unexported fields
}
Returned if the session doesn't exist anymore because it timed out or expired.
func (*InvalidSessionException) Error ¶
func (e *InvalidSessionException) Error() string
func (*InvalidSessionException) ErrorCode ¶
func (e *InvalidSessionException) ErrorCode() string
func (*InvalidSessionException) ErrorFault ¶
func (e *InvalidSessionException) ErrorFault() smithy.ErrorFault
func (*InvalidSessionException) ErrorMessage ¶
func (e *InvalidSessionException) ErrorMessage() string
type LimitExceededException ¶
type LimitExceededException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
Returned if a resource limit such as number of active sessions is exceeded.
func (*LimitExceededException) Error ¶
func (e *LimitExceededException) Error() string
func (*LimitExceededException) ErrorCode ¶
func (e *LimitExceededException) ErrorCode() string
func (*LimitExceededException) ErrorFault ¶
func (e *LimitExceededException) ErrorFault() smithy.ErrorFault
func (*LimitExceededException) ErrorMessage ¶
func (e *LimitExceededException) ErrorMessage() string
type OccConflictException ¶
type OccConflictException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
Returned when a transaction cannot be written to the journal due to a failure in the verification phase of optimistic concurrency control (OCC).
func (*OccConflictException) Error ¶
func (e *OccConflictException) Error() string
func (*OccConflictException) ErrorCode ¶
func (e *OccConflictException) ErrorCode() string
func (*OccConflictException) ErrorFault ¶
func (e *OccConflictException) ErrorFault() smithy.ErrorFault
func (*OccConflictException) ErrorMessage ¶
func (e *OccConflictException) ErrorMessage() string
type Page ¶
type Page struct {
// The token of the next page.
NextPageToken *string
// A structure that contains values in multiple encoding formats.
Values []ValueHolder
// contains filtered or unexported fields
}
Contains details of the fetched page.
type RateExceededException ¶
type RateExceededException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
Returned when the rate of requests exceeds the allowed throughput.
func (*RateExceededException) Error ¶
func (e *RateExceededException) Error() string
func (*RateExceededException) ErrorCode ¶
func (e *RateExceededException) ErrorCode() string
func (*RateExceededException) ErrorFault ¶
func (e *RateExceededException) ErrorFault() smithy.ErrorFault
func (*RateExceededException) ErrorMessage ¶
func (e *RateExceededException) ErrorMessage() string
type StartSessionRequest ¶
type StartSessionRequest struct {
// The name of the ledger to start a new session against.
//
// This member is required.
LedgerName *string
// contains filtered or unexported fields
}
Specifies a request to start a new session.
type StartSessionResult ¶
type StartSessionResult struct {
// Session token of the started session. This SessionToken is required for every
// subsequent command that is issued during the current session.
SessionToken *string
// Contains server-side performance information for the command.
TimingInformation *TimingInformation
// contains filtered or unexported fields
}
Contains the details of the started session.
type StartTransactionRequest ¶
type StartTransactionRequest struct {
// contains filtered or unexported fields
}
Specifies a request to start a transaction.
type StartTransactionResult ¶
type StartTransactionResult struct {
// Contains server-side performance information for the command.
TimingInformation *TimingInformation
// The transaction ID of the started transaction.
TransactionId *string
// contains filtered or unexported fields
}
Contains the details of the started transaction.
type TimingInformation ¶
type TimingInformation struct {
// The amount of time that QLDB spent on processing the command, measured in
// milliseconds.
ProcessingTimeMilliseconds int64
// contains filtered or unexported fields
}
Contains server-side performance information for a command. Amazon QLDB captures timing information between the times when it receives the request and when it sends the corresponding response.
type ValueHolder ¶
type ValueHolder struct {
// An Amazon Ion binary value contained in a ValueHolder structure.
IonBinary []byte
// An Amazon Ion plaintext value contained in a ValueHolder structure.
IonText *string
// contains filtered or unexported fields
}
A structure that can contain a value in multiple encoding formats.
Source Files
¶
- errors.go
- types.go