types

package
v0.0.0-...-68f2935 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2024 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ConflictException

type ConflictException struct {
	Message *string

	ErrorCodeOverride *string

	Reason ConflictExceptionReason
	// contains filtered or unexported fields
}

The specified retention rule lock request can't be completed.

func (*ConflictException) Error

func (e *ConflictException) Error() string

func (*ConflictException) ErrorCode

func (e *ConflictException) ErrorCode() string

func (*ConflictException) ErrorFault

func (e *ConflictException) ErrorFault() smithy.ErrorFault

func (*ConflictException) ErrorMessage

func (e *ConflictException) ErrorMessage() string

type ConflictExceptionReason

type ConflictExceptionReason string
const (
	ConflictExceptionReasonInvalidRuleState ConflictExceptionReason = "INVALID_RULE_STATE"
)

Enum values for ConflictExceptionReason

func (ConflictExceptionReason) Values

Values returns all known values for ConflictExceptionReason. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type InternalServerException

type InternalServerException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

The service could not respond to the request due to an internal problem.

func (*InternalServerException) Error

func (e *InternalServerException) Error() string

func (*InternalServerException) ErrorCode

func (e *InternalServerException) ErrorCode() string

func (*InternalServerException) ErrorFault

func (e *InternalServerException) ErrorFault() smithy.ErrorFault

func (*InternalServerException) ErrorMessage

func (e *InternalServerException) ErrorMessage() string

type LockConfiguration

type LockConfiguration struct {

	// Information about the retention rule unlock delay.
	//
	// This member is required.
	UnlockDelay *UnlockDelay
	// contains filtered or unexported fields
}

Information about a retention rule lock configuration.

type LockState

type LockState string
const (
	LockStateLocked        LockState = "locked"
	LockStatePendingUnlock LockState = "pending_unlock"
	LockStateUnlocked      LockState = "unlocked"
)

Enum values for LockState

func (LockState) Values

func (LockState) Values() []LockState

Values returns all known values for LockState. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type ResourceNotFoundException

type ResourceNotFoundException struct {
	Message *string

	ErrorCodeOverride *string

	Reason ResourceNotFoundExceptionReason
	// contains filtered or unexported fields
}

The specified resource was not found.

func (*ResourceNotFoundException) Error

func (e *ResourceNotFoundException) Error() string

func (*ResourceNotFoundException) ErrorCode

func (e *ResourceNotFoundException) ErrorCode() string

func (*ResourceNotFoundException) ErrorFault

func (*ResourceNotFoundException) ErrorMessage

func (e *ResourceNotFoundException) ErrorMessage() string

type ResourceNotFoundExceptionReason

type ResourceNotFoundExceptionReason string
const (
	ResourceNotFoundExceptionReasonRuleNotFound ResourceNotFoundExceptionReason = "RULE_NOT_FOUND"
)

Enum values for ResourceNotFoundExceptionReason

func (ResourceNotFoundExceptionReason) Values

Values returns all known values for ResourceNotFoundExceptionReason. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type ResourceTag

type ResourceTag struct {

	// The tag key.
	//
	// This member is required.
	ResourceTagKey *string

	// The tag value.
	ResourceTagValue *string
	// contains filtered or unexported fields
}

Information about the resource tags used to identify resources that are retained by the retention rule.

type ResourceType

type ResourceType string
const (
	ResourceTypeEbsSnapshot ResourceType = "EBS_SNAPSHOT"
	ResourceTypeEc2Image    ResourceType = "EC2_IMAGE"
)

Enum values for ResourceType

func (ResourceType) Values

func (ResourceType) Values() []ResourceType

Values returns all known values for ResourceType. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type RetentionPeriod

type RetentionPeriod struct {

	// The unit of time in which the retention period is measured. Currently, only DAYS
	// is supported.
	//
	// This member is required.
	RetentionPeriodUnit RetentionPeriodUnit

	// The period value for which the retention rule is to retain resources. The
	// period is measured using the unit specified for RetentionPeriodUnit.
	//
	// This member is required.
	RetentionPeriodValue *int32
	// contains filtered or unexported fields
}

Information about the retention period for which the retention rule is to retain resources.

type RetentionPeriodUnit

type RetentionPeriodUnit string
const (
	RetentionPeriodUnitDays RetentionPeriodUnit = "DAYS"
)

Enum values for RetentionPeriodUnit

func (RetentionPeriodUnit) Values

Values returns all known values for RetentionPeriodUnit. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type RuleStatus

type RuleStatus string
const (
	RuleStatusPending   RuleStatus = "pending"
	RuleStatusAvailable RuleStatus = "available"
)

Enum values for RuleStatus

func (RuleStatus) Values

func (RuleStatus) Values() []RuleStatus

Values returns all known values for RuleStatus. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type RuleSummary

type RuleSummary struct {

	// The retention rule description.
	Description *string

	// The unique ID of the retention rule.
	Identifier *string

	// The lock state for the retention rule.
	//
	//   - locked - The retention rule is locked and can't be modified or deleted.
	//
	//   - pending_unlock - The retention rule has been unlocked but it is still within
	//   the unlock delay period. The retention rule can be modified or deleted only
	//   after the unlock delay period has expired.
	//
	//   - unlocked - The retention rule is unlocked and it can be modified or deleted
	//   by any user with the required permissions.
	//
	//   - null - The retention rule has never been locked. Once a retention rule has
	//   been locked, it can transition between the locked and unlocked states only; it
	//   can never transition back to null .
	LockState LockState

	// Information about the retention period for which the retention rule is to
	// retain resources.
	RetentionPeriod *RetentionPeriod

	// The Amazon Resource Name (ARN) of the retention rule.
	RuleArn *string
	// contains filtered or unexported fields
}

Information about a Recycle Bin retention rule.

type ServiceQuotaExceededException

type ServiceQuotaExceededException struct {
	Message *string

	ErrorCodeOverride *string

	Reason ServiceQuotaExceededExceptionReason
	// contains filtered or unexported fields
}

The request would cause a service quota for the number of tags per resource to be exceeded.

func (*ServiceQuotaExceededException) Error

func (*ServiceQuotaExceededException) ErrorCode

func (e *ServiceQuotaExceededException) ErrorCode() string

func (*ServiceQuotaExceededException) ErrorFault

func (*ServiceQuotaExceededException) ErrorMessage

func (e *ServiceQuotaExceededException) ErrorMessage() string

type ServiceQuotaExceededExceptionReason

type ServiceQuotaExceededExceptionReason string
const (
	ServiceQuotaExceededExceptionReasonServiceQuotaExceeded ServiceQuotaExceededExceptionReason = "SERVICE_QUOTA_EXCEEDED"
)

Enum values for ServiceQuotaExceededExceptionReason

func (ServiceQuotaExceededExceptionReason) Values

Values returns all known values for ServiceQuotaExceededExceptionReason. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type Tag

type Tag struct {

	// The tag key.
	//
	// This member is required.
	Key *string

	// The tag value.
	//
	// This member is required.
	Value *string
	// contains filtered or unexported fields
}

Information about the tags to assign to the retention rule.

type UnlockDelay

type UnlockDelay struct {

	// The unit of time in which to measure the unlock delay. Currently, the unlock
	// delay can be measure only in days.
	//
	// This member is required.
	UnlockDelayUnit UnlockDelayUnit

	// The unlock delay period, measured in the unit specified for UnlockDelayUnit.
	//
	// This member is required.
	UnlockDelayValue *int32
	// contains filtered or unexported fields
}

Information about the retention rule unlock delay. The unlock delay is the period after which a retention rule can be modified or edited after it has been unlocked by a user with the required permissions. The retention rule can't be modified or deleted during the unlock delay.

type UnlockDelayUnit

type UnlockDelayUnit string
const (
	UnlockDelayUnitDays UnlockDelayUnit = "DAYS"
)

Enum values for UnlockDelayUnit

func (UnlockDelayUnit) Values

func (UnlockDelayUnit) Values() []UnlockDelayUnit

Values returns all known values for UnlockDelayUnit. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type ValidationException

type ValidationException struct {
	Message *string

	ErrorCodeOverride *string

	Reason ValidationExceptionReason
	// contains filtered or unexported fields
}

One or more of the parameters in the request is not valid.

func (*ValidationException) Error

func (e *ValidationException) Error() string

func (*ValidationException) ErrorCode

func (e *ValidationException) ErrorCode() string

func (*ValidationException) ErrorFault

func (e *ValidationException) ErrorFault() smithy.ErrorFault

func (*ValidationException) ErrorMessage

func (e *ValidationException) ErrorMessage() string

type ValidationExceptionReason

type ValidationExceptionReason string
const (
	ValidationExceptionReasonInvalidPageToken      ValidationExceptionReason = "INVALID_PAGE_TOKEN"
	ValidationExceptionReasonInvalidParameterValue ValidationExceptionReason = "INVALID_PARAMETER_VALUE"
)

Enum values for ValidationExceptionReason

func (ValidationExceptionReason) Values

Values returns all known values for ValidationExceptionReason. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

Source Files

  • enums.go
  • errors.go
  • types.go

Jump to