types

package
v0.0.0-...-68f2935 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2024 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Checksum

type Checksum struct {

	// The checksum of the model.
	Sum *string

	// The type of the checksum.
	Type ChecksumType
	// contains filtered or unexported fields
}

Information about the checksum of a model deployed on a device.

type ChecksumType

type ChecksumType string
const (
	ChecksumTypeSha1 ChecksumType = "SHA1"
)

Enum values for ChecksumType

func (ChecksumType) Values

func (ChecksumType) Values() []ChecksumType

Values returns all known values for ChecksumType. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type Definition

type Definition struct {

	// The checksum information of the model.
	Checksum *Checksum

	// The unique model handle.
	ModelHandle *string

	// The absolute S3 location of the model.
	S3Url *string

	// The desired state of the model.
	State ModelState
	// contains filtered or unexported fields
}

type DeploymentModel

type DeploymentModel struct {

	// The desired state of the model.
	DesiredState ModelState

	// The unique handle of the model.
	ModelHandle *string

	// The name of the model.
	ModelName *string

	// The version of the model.
	ModelVersion *string

	// Returns the error message if there is a rollback.
	RollbackFailureReason *string

	// Returns the current state of the model.
	State ModelState

	// Returns the deployment status of the model.
	Status DeploymentStatus

	// Returns the error message for the deployment status result.
	StatusReason *string
	// contains filtered or unexported fields
}

type DeploymentResult

type DeploymentResult struct {

	// The timestamp of when the deployment was ended, and the agent got the
	// deployment results.
	DeploymentEndTime *time.Time

	// Returns a list of models deployed on the agent.
	DeploymentModels []DeploymentModel

	// The name and unique ID of the deployment.
	DeploymentName *string

	// The timestamp of when the deployment was started on the agent.
	DeploymentStartTime *time.Time

	// Returns the bucket error code.
	DeploymentStatus *string

	// Returns the detailed error message.
	DeploymentStatusMessage *string
	// contains filtered or unexported fields
}

Information about the result of a deployment on an edge device that is registered with SageMaker Edge Manager.

type DeploymentStatus

type DeploymentStatus string
const (
	DeploymentStatusSuccess DeploymentStatus = "SUCCESS"
	DeploymentStatusFail    DeploymentStatus = "FAIL"
)

Enum values for DeploymentStatus

func (DeploymentStatus) Values

Values returns all known values for DeploymentStatus. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type DeploymentType

type DeploymentType string
const (
	DeploymentTypeModel DeploymentType = "Model"
)

Enum values for DeploymentType

func (DeploymentType) Values

func (DeploymentType) Values() []DeploymentType

Values returns all known values for DeploymentType. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type EdgeDeployment

type EdgeDeployment struct {

	// Returns a list of Definition objects.
	Definitions []Definition

	// The name and unique ID of the deployment.
	DeploymentName *string

	// Determines whether to rollback to previous configuration if deployment fails.
	FailureHandlingPolicy FailureHandlingPolicy

	// The type of the deployment.
	Type DeploymentType
	// contains filtered or unexported fields
}

Information about a deployment on an edge device that is registered with SageMaker Edge Manager.

type EdgeMetric

type EdgeMetric struct {

	// The dimension of metrics published.
	Dimension *string

	// Returns the name of the metric.
	MetricName *string

	// Timestamp of when the metric was requested.
	Timestamp *time.Time

	// Returns the value of the metric.
	Value *float64
	// contains filtered or unexported fields
}

Information required for edge device metrics.

type FailureHandlingPolicy

type FailureHandlingPolicy string
const (
	FailureHandlingPolicyRollbackOnFailure FailureHandlingPolicy = "ROLLBACK_ON_FAILURE"
	FailureHandlingPolicyDoNothing         FailureHandlingPolicy = "DO_NOTHING"
)

Enum values for FailureHandlingPolicy

func (FailureHandlingPolicy) Values

Values returns all known values for FailureHandlingPolicy. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

type InternalServiceException

type InternalServiceException struct {
	Message *string

	ErrorCodeOverride *string
	// contains filtered or unexported fields
}

An internal failure occurred. Try your request again. If the problem persists, contact Amazon Web Services customer support.

func (*InternalServiceException) Error

func (e *InternalServiceException) Error() string

func (*InternalServiceException) ErrorCode

func (e *InternalServiceException) ErrorCode() string

func (*InternalServiceException) ErrorFault

func (e *InternalServiceException) ErrorFault() smithy.ErrorFault

func (*InternalServiceException) ErrorMessage

func (e *InternalServiceException) ErrorMessage() string

type Model

type Model struct {

	// The timestamp of the last inference that was made.
	LatestInference *time.Time

	// The timestamp of the last data sample taken.
	LatestSampleTime *time.Time

	// Information required for model metrics.
	ModelMetrics []EdgeMetric

	// The name of the model.
	ModelName *string

	// The version of the model.
	ModelVersion *string
	// contains filtered or unexported fields
}

Information about a model deployed on an edge device that is registered with SageMaker Edge Manager.

type ModelState

type ModelState string
const (
	ModelStateDeploy   ModelState = "DEPLOY"
	ModelStateUndeploy ModelState = "UNDEPLOY"
)

Enum values for ModelState

func (ModelState) Values

func (ModelState) Values() []ModelState

Values returns all known values for ModelState. Note that this can be expanded in the future, and so it is only as up to date as the client.

The ordering of this slice is not guaranteed to be stable across updates.

Source Files

  • enums.go
  • errors.go
  • types.go

Jump to