Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccountInfo ¶
type AccountInfo struct {
// The identifier of the AWS account that is assigned to the user.
AccountId *string
// The display name of the AWS account that is assigned to the user.
AccountName *string
// The email address of the AWS account that is assigned to the user.
EmailAddress *string
// contains filtered or unexported fields
}
Provides information about your AWS account.
type InvalidRequestException ¶
type InvalidRequestException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
Indicates that a problem occurred with the input to the request. For example, a required parameter might be missing or out of range.
func (*InvalidRequestException) Error ¶
func (e *InvalidRequestException) Error() string
func (*InvalidRequestException) ErrorCode ¶
func (e *InvalidRequestException) ErrorCode() string
func (*InvalidRequestException) ErrorFault ¶
func (e *InvalidRequestException) ErrorFault() smithy.ErrorFault
func (*InvalidRequestException) ErrorMessage ¶
func (e *InvalidRequestException) ErrorMessage() string
type ResourceNotFoundException ¶
type ResourceNotFoundException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The specified resource doesn't exist.
func (*ResourceNotFoundException) Error ¶
func (e *ResourceNotFoundException) Error() string
func (*ResourceNotFoundException) ErrorCode ¶
func (e *ResourceNotFoundException) ErrorCode() string
func (*ResourceNotFoundException) ErrorFault ¶
func (e *ResourceNotFoundException) ErrorFault() smithy.ErrorFault
func (*ResourceNotFoundException) ErrorMessage ¶
func (e *ResourceNotFoundException) ErrorMessage() string
type RoleCredentials ¶
type RoleCredentials struct {
// The identifier used for the temporary security credentials. For more
// information, see [Using Temporary Security Credentials to Request Access to AWS Resources]in the AWS IAM User Guide.
//
// [Using Temporary Security Credentials to Request Access to AWS Resources]: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_use-resources.html
AccessKeyId *string
// The date on which temporary security credentials expire.
Expiration int64
// The key that is used to sign the request. For more information, see [Using Temporary Security Credentials to Request Access to AWS Resources] in the AWS
// IAM User Guide.
//
// [Using Temporary Security Credentials to Request Access to AWS Resources]: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_use-resources.html
SecretAccessKey *string
// The token used for temporary credentials. For more information, see [Using Temporary Security Credentials to Request Access to AWS Resources] in the AWS
// IAM User Guide.
//
// [Using Temporary Security Credentials to Request Access to AWS Resources]: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_use-resources.html
SessionToken *string
// contains filtered or unexported fields
}
Provides information about the role credentials that are assigned to the user.
type RoleInfo ¶
type RoleInfo struct {
// The identifier of the AWS account assigned to the user.
AccountId *string
// The friendly name of the role that is assigned to the user.
RoleName *string
// contains filtered or unexported fields
}
Provides information about the role that is assigned to the user.
type TooManyRequestsException ¶
type TooManyRequestsException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
Indicates that the request is being made too frequently and is more than what the server can handle.
func (*TooManyRequestsException) Error ¶
func (e *TooManyRequestsException) Error() string
func (*TooManyRequestsException) ErrorCode ¶
func (e *TooManyRequestsException) ErrorCode() string
func (*TooManyRequestsException) ErrorFault ¶
func (e *TooManyRequestsException) ErrorFault() smithy.ErrorFault
func (*TooManyRequestsException) ErrorMessage ¶
func (e *TooManyRequestsException) ErrorMessage() string
type UnauthorizedException ¶
type UnauthorizedException struct {
// contains filtered or unexported fields
}
Indicates that the request is not authorized. This can happen due to an invalid access token in the request.
func (*UnauthorizedException) Error ¶
func (e *UnauthorizedException) Error() string
func (*UnauthorizedException) ErrorCode ¶
func (e *UnauthorizedException) ErrorCode() string
func (*UnauthorizedException) ErrorFault ¶
func (e *UnauthorizedException) ErrorFault() smithy.ErrorFault
func (*UnauthorizedException) ErrorMessage ¶
func (e *UnauthorizedException) ErrorMessage() string
Source Files
¶
- errors.go
- types.go
Click to show internal directories.
Click to hide internal directories.