Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Dimension ¶
type Dimension string
const ( DimensionService Dimension = "SERVICE" DimensionOperation Dimension = "OPERATION" DimensionUsageType Dimension = "USAGE_TYPE" DimensionRegion Dimension = "REGION" DimensionFreeTierType Dimension = "FREE_TIER_TYPE" DimensionDescription Dimension = "DESCRIPTION" DimensionUsagePercentage Dimension = "USAGE_PERCENTAGE" )
Enum values for Dimension
type DimensionValues ¶
type DimensionValues struct {
// The name of the dimension that you want to filter on.
//
// This member is required.
Key Dimension
// The match options that you can use to filter your results. You can specify only
// one of these values in the array.
//
// This member is required.
MatchOptions []MatchOption
// The metadata values you can specify to filter upon, so that the results all
// match at least one of the specified values.
//
// This member is required.
Values []string
// contains filtered or unexported fields
}
Contains the specifications for the filters to use for your request.
type Expression ¶
type Expression struct {
// Return results that match all Expressions that you specified in the array.
And []Expression
// The specific dimension, values, and match type to filter objects with.
Dimensions *DimensionValues
// Return results that don’t match the Expression that you specified.
Not *Expression
// Return results that match any of the Expressions that you specified. in the
// array.
Or []Expression
// contains filtered or unexported fields
}
Use Expression to filter in the GetFreeTierUsage API operation.
You can use the following patterns:
Simple dimension values ( Dimensions root operator)
Complex expressions with logical operators ( AND , NOT , and OR root operators).
For simple dimension values, you can set the dimension name, values, and match type for the filters that you plan to use.
Example for simple dimension values ¶
You can filter to match exactly for REGION==us-east-1 OR REGION==us-west-1 .
The corresponding Expression appears like the following: { "Dimensions": { "Key": "REGION", "Values": [ "us-east-1", "us-west-1" ], "MatchOptions": ["EQUALS"] } }
As shown in the previous example, lists of dimension values are combined with OR when you apply the filter.
For complex expressions with logical operators, you can have nested expressions to use the logical operators and specify advanced filtering.
Example for complex expressions with logical operators ¶
You can filter by ((REGION == us-east-1 OR REGION == us-west-1) OR (SERVICE CONTAINS AWSLambda)) AND (USAGE_TYPE !CONTAINS DataTransfer) .
The corresponding Expression appears like the following: { "And": [ {"Or": [ {"Dimensions": { "Key": "REGION", "Values": [ "us-east-1", "us-west-1" ], "MatchOptions": ["EQUALS"] }}, {"Dimensions": { "Key": "SERVICE", "Values": ["AWSLambda"], "MatchOptions": ["CONTAINS"] } } ]}, {"Not": {"Dimensions": { "Key": "USAGE_TYPE", "Values": ["DataTransfer"], "MatchOptions": ["CONTAINS"] }}} ] }
In the following Contents, you must specify exactly one of the following root operators.
type FreeTierUsage ¶
type FreeTierUsage struct {
// Describes the actual usage accrued month-to-day (MTD) that you've used so far.
ActualUsageAmount float64
// The description of the Free Tier offer.
Description *string
// Describes the forecasted usage by the month that you're expected to use.
ForecastedUsageAmount float64
// Describes the type of the Free Tier offer. For example, the offer can be "12
// Months Free" , "Always Free" , and "Free Trial" .
FreeTierType *string
// Describes the maximum usage allowed in Free Tier.
Limit float64
// Describes usageType more granularly with the specific Amazon Web Service API
// operation. For example, this can be the RunInstances API operation for Amazon
// Elastic Compute Cloud.
Operation *string
// Describes the Amazon Web Services Region for which this offer is applicable
Region *string
// The name of the Amazon Web Service providing the Free Tier offer. For example,
// this can be Amazon Elastic Compute Cloud.
Service *string
// Describes the unit of the usageType , such as Hrs .
Unit *string
// Describes the usage details of the offer. For example, this might be
// Global-BoxUsage:freetrial .
UsageType *string
// contains filtered or unexported fields
}
Consists of a Amazon Web Services Free Tier offer’s metadata and your data usage for the offer.
type InternalServerException ¶
type InternalServerException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
An unexpected error occurred during the processing of your request.
func (*InternalServerException) Error ¶
func (e *InternalServerException) Error() string
func (*InternalServerException) ErrorCode ¶
func (e *InternalServerException) ErrorCode() string
func (*InternalServerException) ErrorFault ¶
func (e *InternalServerException) ErrorFault() smithy.ErrorFault
func (*InternalServerException) ErrorMessage ¶
func (e *InternalServerException) ErrorMessage() string
type MatchOption ¶
type MatchOption string
const ( MatchOptionEquals MatchOption = "EQUALS" MatchOptionStartsWith MatchOption = "STARTS_WITH" MatchOptionEndsWith MatchOption = "ENDS_WITH" MatchOptionContains MatchOption = "CONTAINS" MatchOptionGreaterThanOrEqual MatchOption = "GREATER_THAN_OR_EQUAL" )
Enum values for MatchOption
func (MatchOption) Values ¶
func (MatchOption) Values() []MatchOption
Values returns all known values for MatchOption. Note that this can be expanded in the future, and so it is only as up to date as the client.
The ordering of this slice is not guaranteed to be stable across updates.
type ThrottlingException ¶
type ThrottlingException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The request was denied due to request throttling.
func (*ThrottlingException) Error ¶
func (e *ThrottlingException) Error() string
func (*ThrottlingException) ErrorCode ¶
func (e *ThrottlingException) ErrorCode() string
func (*ThrottlingException) ErrorFault ¶
func (e *ThrottlingException) ErrorFault() smithy.ErrorFault
func (*ThrottlingException) ErrorMessage ¶
func (e *ThrottlingException) ErrorMessage() string
type ValidationException ¶
type ValidationException struct {
Message *string
ErrorCodeOverride *string
// contains filtered or unexported fields
}
The input fails to satisfy the constraints specified by an Amazon Web Service.
func (*ValidationException) Error ¶
func (e *ValidationException) Error() string
func (*ValidationException) ErrorCode ¶
func (e *ValidationException) ErrorCode() string
func (*ValidationException) ErrorFault ¶
func (e *ValidationException) ErrorFault() smithy.ErrorFault
func (*ValidationException) ErrorMessage ¶
func (e *ValidationException) ErrorMessage() string
Source Files
¶
- enums.go
- errors.go
- types.go